function [params] = estinf_HO(input,mat)

    cd('../subroutines')
    tStart = tic;    

    % Load options
    sample     = input.sample;
    h          = input.h;
    mod        = input.mod;
    firmsize   = input.firmsize;
    estfolder  = input.estfolder;
    saveres    = input.saveres; 
    if sample == 1
        estfolder = strcat(estfolder, 'sample/');
    end       
       
    % Report
    fprintf('********************************************************* \n')
    fprintf('Report date    = %s \n', datestr(now))
    fprintf('Future wages   = %d \n', h)
    fprintf('Model          = %d \n', mod)
    fprintf('Firm size lim  = %d \n', firmsize)
    fprintf('Save results   = %d \n', saveres)
    fprintf('Sample trial   = %d \n', sample)
    fprintf('********************************************************* \n')

    % Initialize
    fprintf('Initialize and Estimate ... \n') 
    [params]      = initial_params();
    [params.dhat] = initial_dhat(mat,params);

    % Estimation and inference
    [params,temp_glo] = search_global_ho(mat,params);          %global
    [Betahat,params]  = search_local_ho(mat,params,temp_glo);  %local
    [params,estfin] = search_finalbeta_ho(mat,params,Betahat); %final        

    % Saving
    fsval = num2str(firmsize);
    hval  = num2str(h);
    mval  = num2str(mod);
    if saveres == 1
        save(strcat(estfolder,'params_f',fsval,'w',hval,'m',mval), '-struct','params')
        if size(estfin,2) == 1 % no multiple betas
            estfin = estfin{1};
            save(strcat(estfolder,'est_f',fsval,'w',hval,'m',mval), '-struct','estfin')
        else                   % if multiple betas
            save(strcat(estfolder,'est_f',fsval,'w',hval,'m',mval), 'estfin')
        end
    end
    
    % Report
    betafin = params.betafin; 
    tEnd = toc(tStart)/60;
    fprintf('betafin = %2.5f for h = %d in mod %d takes %5.2f mins \n', betafin, h, mod, tEnd)     
    
    cd('../main_progs')
    
end