function [C] = get_C(idw_raw,ida_raw,idp_raw,W,X0size)
    
    % Basic setup
    w     = length(unique(idw_raw)); % num of workers
    max_a = length(unique(ida_raw));
    Cm = sparse(size(W,1),size(W,2));   
    
    % Get C
    for a = 1:1:max_a   
        sel=ismember(ida_raw,a);
        C0 =sparse(sum(sel),w);
        idw=idw_raw(sel);
        idp=idp_raw(sel);
        [~,~,n]=unique(idp);
        idp = n;    %relabel
        Pt = sparse(1:length(idp),idp,1);
        Ct = Pt*Pt';
        Ct = Ct - speye(size(Ct));
        Ct = Ct./sum(Ct);
        C0(:,idw) = Ct;
        Cm(sel,:) = C0;
    end
    Ca = sparse(size(W,1),X0size);
    C  = [Cm,Ca];

    % Check
    numcoworkers = sum((Cm~=0),2);  %Sum up NUMBER of coworkers
    nocoworker = sum(numcoworkers==0);
    fprintf('  How many workers do not have a coworker? %d \n', full(nocoworker))
    
    % Reporting
    avgcoworkers = mean(numcoworkers);
    mdncoworkers = median(numcoworkers);
    stdcoworkers = std(numcoworkers);
    fprintf('  Average number of coworkers %3.1f \n', full(avgcoworkers))
    fprintf('  Median number of coworkers %3.1f \n', full(mdncoworkers))
    fprintf('  Standard deviation of coworkers %3.1f \n', full(stdcoworkers))
    
end