clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Tables"

********************************************************************************
* Worker level
********************************************************************************
foreach type in better worse {

	use "$data/worker_dataset.dta", clear
	rename treat`type' treated
	keep if treated!=.

	* Matching
	keep if k==-3
	xi i.prov i.sector_str, noomit
	egen sector_num=group(ateco91)
	global covs "lrw_m4 lrw_m3 lrw_m2 weeks alphadec age female ten blue psi lnfirmsize"
	keep cod_pgr sector_num treated $covs _Isector_st* _Iprov*

	psmatch2 treated $covs  _Isector* _Iprov*, caliper(.001) noreplace neighbor(1)
	gen pair = _id if _treated==0 
	replace pair = _n1 if _treated==1
	bysort pair: egen paircount = count(pair)
	gen matched=paircount==2
	tab treated if matched
	
	label variable lrw_m4 "Wage -4"
	label variable lrw_m3 "Wage -3"
	label variable lrw_m2 "Wage -2"
	label variable weeks "Weeks worked"
	label variable alphadec "AKM worker effect decile"
	label variable age "Age"
	label variable female "Female"
	label variable ten "Tenure"
	label variable blue "Blue-collar"
	label variable psi "AKM firm effect"
	label variable lnfirmsize "Log firm size"
	 
	label variable _Isector_st_1 "Manufacturing"
	label variable _Isector_st_2 "Construction"
	label variable _Isector_st_3 "Wholesale"
	label variable _Isector_st_4 "Accommodation"
	label variable _Isector_st_5 "Transports"
	label variable _Isector_st_6 "Finance"
	label variable _Isector_st_7 "Services"
	label variable _Isector_st_8 "Health"
	label variable _Isector_st_9 "Domestic"
	label variable _Isector_st_10 "Other"
	
	label variable _Iprov_1 "Belluno"
	label variable _Iprov_2 "Padua"
	label variable _Iprov_3 "Rovigo"
	label variable _Iprov_4 "Treviso"
	label variable _Iprov_5 "Venice"
	label variable _Iprov_6 "Vicenza"
	label variable _Iprov_7 "Verona"
	
	global covs $covs _Isector_st_1 _Isector_st_2 _Isector_st_3 _Isector_st_4 _Isector_st_5 _Isector_st_6 _Isector_st_7 _Isector_st_8 _Isector_st_9 _Isector_st_10 _Iprov_1 _Iprov_2 _Iprov_3 _Iprov_4 _Iprov_5 _Iprov_6 _Iprov_7
	foreach var in $covs {
		
		* Store variable labels
		global lbe_`var' : variable label `var'
		
		* Store difference and p-values unmatched sample
		reg `var' treated, cluster(sector_num)
		local t = _b[treated]/_se[treated]
		local p = 2*ttail(e(df_r),abs(`t'))
		if `p'>=0.1 			local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		if `p'<0.1  & `p'>=0.05 local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "*"
		if `p'<0.05 & `p'>=0.01 local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "**"
		if `p'<0.01  			local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "***"		
		local bu_`var'_`type' : di %6.3f _b[treated]
		
		* Store difference and p-values matched sample
		reg `var' treated if matched==1, cluster(sector_num)
		local t = _b[treated]/_se[treated]
		local p = 2*ttail(e(df_r),abs(`t'))
		if `p'>=0.1 			local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		if `p'<0.1  & `p'>=0.05 local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "*"
		if `p'<0.05 & `p'>=0.01 local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "**"
		if `p'<0.01  			local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "***"
		local bm_`var'_`type' : di %6.3f _b[treated]
	}
	
	* Store counts
	count if treated==1
	local nu_treated_`type'=r(N)
	count if treated==0
	local nu_control_`type'=r(N)
	count if treated==1 & matched==1
	local nm_treated_`type'=r(N)
	count if treated==0 & matched==1
	local nm_control_`type'=r(N)
}
	
texdoc init $table/BalanceTestWorker.tex, replace force

	tex \begin{tabular}{lcccccccc} \toprule \toprule 
	tex & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) \\ \midrule
	tex & \multicolumn{4}{c}{High-quality peers} & \multicolumn{4}{c}{Low-quality peers} \\ \cmidrule(lr){2-5}\cmidrule(lr){6-9}
	tex & \multicolumn{2}{c}{Unmatched} & \multicolumn{2}{c}{Matched} & \multicolumn{2}{c}{Unmatched} & \multicolumn{2}{c}{Matched} \\ \cmidrule(lr){2-3}\cmidrule(lr){4-5}\cmidrule(lr){6-7}\cmidrule(lr){8-9}
	tex & Diff. & P-value & Diff. & P-value & Diff. & P-value & Diff. & P-value \\
	tex \midrule 
	foreach var in $covs {
		tex ${lbe_`var'} & `bu_`var'_better' & `pu_`var'_better' & `bm_`var'_better' & `pm_`var'_better' & `bu_`var'_worse' & `pu_`var'_worse' & `bm_`var'_worse' & `pm_`var'_worse' \\
	}
	tex \midrule
	tex N. treated & \multicolumn{2}{c}{`nu_treated_better'} & \multicolumn{2}{c}{`nm_treated_better'} & \multicolumn{2}{c}{`nu_treated_worse'} & \multicolumn{2}{c}{`nm_treated_worse'} \\
	tex N. control & \multicolumn{2}{c}{`nu_control_better'} & \multicolumn{2}{c}{`nm_control_better'} & \multicolumn{2}{c}{`nu_control_worse'} & \multicolumn{2}{c}{`nm_control_worse'} \\
	tex \bottomrule \bottomrule
	tex \end{tabular}

texdoc close




********************************************************************************
* Firm-level LEAVE
********************************************************************************
local data "better worse"

foreach type of local data {

	use "$data/leave_`type'_for_matching", clear
	rename treat treated

	set seed 20200628 // 20200628  
	local bs "ricavi val_added attivo reddito_op reddito_netto"
	foreach v of local bs {
		gen random_`v' = runiform()*1e5
		replace `v' = random_`v' if merge_md == 1
		drop random_`v'
	}

	foreach var in wwage {
		gen aux1=`var' if k==-4
		gen aux2=`var' if k==-3
		gen aux3=`var' if k==-2
		local k=4
		forvalues i=1/3 {
			bys matr_az: egen `var'_m`k'=mean(aux`i')
			local k=`k'-1
		}
		drop aux*
	}

	* Keep only observations at time t-3 and perform matching
	keep if k==-3
	global covs "wwage_m4 wwage_m3 wwage_m2 alpha psi age female blue n firm_age val_added ricavi"
	keep matr_az $covs sector prov treated
	xi i.prov i.sector, noomit

	* Propensity score
	psmatch2 treated $covs _Isector* _Iprov*, caliper(.001) noreplace neighbor(1)
	gen pair = _id if _treated==0 
	replace pair = _n1 if _treated==1
	bysort pair: egen paircount = count(pair)
	gen matched=paircount==2

	label variable wwage_m4 "Mean wage -4"
	label variable wwage_m3 "Mean wage -3"
	label variable wwage_m2 "Mean wage -2"
	label variable alpha "AKM worker effect"
	label variable psi "AKM firm effect"
	label variable age "Employees' mean age"
	label variable female "Share female"
	label variable blue "Share blue-collar"
	label variable n "Firm size"
	label variable firm_age "Firm age"
	label variable val_added "Value added"
	label variable ricavi "Revenues"
	
	label variable _Isector_1 "Manufacturing"
	label variable _Isector_2 "Construction"
	label variable _Isector_3 "Wholesale"
	label variable _Isector_4 "Accommodation"
	label variable _Isector_5 "Transports"
	label variable _Isector_6 "Finance"
	label variable _Isector_7 "Services"
	label variable _Isector_8 "Health"
	label variable _Isector_9 "Domestic"
	label variable _Isector_10 "Other"
	
	label variable _Iprov_1 "Belluno"
	label variable _Iprov_2 "Padua"
	label variable _Iprov_3 "Rovigo"
	label variable _Iprov_4 "Treviso"
	label variable _Iprov_5 "Venice"
	label variable _Iprov_6 "Vicenza"
	label variable _Iprov_7 "Verona"
	
	global covs $covs _Isector_1 _Isector_2 _Isector_3 _Isector_4 _Isector_5 _Isector_6 _Isector_7 _Isector_8 _Isector_9 _Isector_10 _Iprov_1 _Iprov_2 _Iprov_3 _Iprov_4 _Iprov_5 _Iprov_6 _Iprov_7
	
	foreach var in $covs {
		
		* Store variable labels
		global lbe_`var' : variable label `var'
		
		* Store difference and p-values unmatched sample
		reg `var' treated, r
		local t = _b[treated]/_se[treated]
		local p = 2*ttail(e(df_r),abs(`t'))
		if `p'>=0.1 			local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		if `p'<0.1  & `p'>=0.05 local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "*"
		if `p'<0.05 & `p'>=0.01 local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "**"
		if `p'<0.01  			local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "***"
		local bu_`var'_`type' : di %6.3f _b[treated]
		
		* Store difference and p-values matched sample
		reg `var' treated if matched==1, r
		local t = _b[treated]/_se[treated]
		local p = 2*ttail(e(df_r),abs(`t'))
		if `p'>=0.1 			local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		if `p'<0.1  & `p'>=0.05 local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "*"
		if `p'<0.05 & `p'>=0.01 local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "**"
		if `p'<0.01  			local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "***"
		local bm_`var'_`type' : di %6.3f _b[treated]
	}
	
	* Store counts
	count if treated==1
	local nu_treated_`type'=r(N)
	count if treated==0
	local nu_control_`type'=r(N)
	count if treated==1 & matched==1
	local nm_treated_`type'=r(N)
	count if treated==0 & matched==1
	local nm_control_`type'=r(N)
}

texdoc init $table/BalanceTestLeave.tex, replace force

	tex \begin{tabular}{lcccccccc} \toprule \toprule 
	tex & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) \\ \midrule
	tex & \multicolumn{4}{c}{High-quality mover} & \multicolumn{4}{c}{Low-quality mover} \\ \cmidrule(lr){2-5}\cmidrule(lr){6-9}
	tex & \multicolumn{2}{c}{Unmatched} & \multicolumn{2}{c}{Matched} & \multicolumn{2}{c}{Unmatched} & \multicolumn{2}{c}{Matched} \\ \cmidrule(lr){2-3}\cmidrule(lr){4-5}\cmidrule(lr){6-7}\cmidrule(lr){8-9}
	tex & Diff. & P-value & Diff. & P-value & Diff. & P-value & Diff. & P-value \\
	tex \midrule 
	foreach var in $covs {
		tex ${lbe_`var'} & `bu_`var'_better' & `pu_`var'_better' & `bm_`var'_better' & `pm_`var'_better' & `bu_`var'_worse' & `pu_`var'_worse' & `bm_`var'_worse' & `pm_`var'_worse' \\
	}
	tex \midrule
	tex N. treated & \multicolumn{2}{c}{`nu_treated_better'} & \multicolumn{2}{c}{`nm_treated_better'} & \multicolumn{2}{c}{`nu_treated_worse'} & \multicolumn{2}{c}{`nm_treated_worse'} \\
	tex N. control & \multicolumn{2}{c}{`nu_control_better'} & \multicolumn{2}{c}{`nm_control_better'} & \multicolumn{2}{c}{`nu_control_worse'} & \multicolumn{2}{c}{`nm_control_worse'} \\
	tex \bottomrule \bottomrule
	tex \end{tabular}

texdoc close



********************************************************************************
* Firm-level HIRE
********************************************************************************
local data "better worse"

foreach type of local data {

	use "${data}/hire_`type'_for_matching", clear
	rename treat treated

	set seed 20200628  
	local bs "ricavi val_added attivo reddito_op reddito_netto"
	foreach v of local bs {
		gen random_`v' = runiform()*1e5
		replace `v' = random_`v' if merge_md == 1
		drop random_`v'
	}

	foreach var in wwage {
		gen aux1=`var' if k==-4
		gen aux2=`var' if k==-3
		gen aux3=`var' if k==-2
		local k=4
		forvalues i=1/3 {
			bys matr_az: egen `var'_m`k'=mean(aux`i')
			local k=`k'-1
		}
		drop aux*
	}

	* Keep only observations at time t-3 and perform matching
	keep if k==-3
	global covs "wwage_m4 wwage_m3 wwage_m2 alpha psi age female blue n firm_age val_added ricavi"
	keep matr_az $covs sector prov treated
	xi i.prov i.sector, noomit

	* Propensity score
	psmatch2 treated $covs _Isector* _Iprov*, caliper(.001) noreplace neighbor(1)
	gen pair = _id if _treated==0 
	replace pair = _n1 if _treated==1
	bysort pair: egen paircount = count(pair)
	gen matched=paircount==2

	label variable wwage_m4 "Mean wage -4"
	label variable wwage_m3 "Mean wage -3"
	label variable wwage_m2 "Mean wage -2"
	label variable alpha "AKM worker effect"
	label variable psi "AKM firm effect"
	label variable age "Employees' mean age"
	label variable female "Share female"
	label variable blue "Share blue-collar"
	label variable n "Firm size"
	label variable firm_age "Firm age"
	label variable val_added "Value added"
	label variable ricavi "Revenues"
	
	label variable _Isector_1 "Manufacturing"
	label variable _Isector_2 "Construction"
	label variable _Isector_3 "Wholesale"
	label variable _Isector_4 "Accommodation"
	label variable _Isector_5 "Transports"
	label variable _Isector_6 "Finance"
	label variable _Isector_7 "Services"
	label variable _Isector_8 "Health"
	label variable _Isector_9 "Domestic"
	label variable _Isector_10 "Other"
	
	label variable _Iprov_1 "Belluno"
	label variable _Iprov_2 "Padua"
	label variable _Iprov_3 "Rovigo"
	label variable _Iprov_4 "Treviso"
	label variable _Iprov_5 "Venice"
	label variable _Iprov_6 "Vicenza"
	label variable _Iprov_7 "Verona"
	
	global covs $covs _Isector_1 _Isector_2 _Isector_3 _Isector_4 _Isector_5 _Isector_6 _Isector_7 _Isector_8 _Isector_9 _Isector_10 _Iprov_1 _Iprov_2 _Iprov_3 _Iprov_4 _Iprov_5 _Iprov_6 _Iprov_7
	foreach var in $covs {
		
		* Store variable labels
		global lbe_`var' : variable label `var'
		
		* Store difference and p-values unmatched sample
		reg `var' treated, r
		local t = _b[treated]/_se[treated]
		*local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		local p = 2*ttail(e(df_r),abs(`t'))
		if `p'>=0.1 			local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		if `p'<0.1  & `p'>=0.05 local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "*"
		if `p'<0.05 & `p'>=0.01 local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "**"
		if `p'<0.01  			local pu_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "***"
		local bu_`var'_`type' : di %6.3f _b[treated]
		
		* Store difference and p-values matched sample
		reg `var' treated if matched==1, r
		local t = _b[treated]/_se[treated]
		local p = 2*ttail(e(df_r),abs(`t'))
		if `p'>=0.1 			local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		if `p'<0.1  & `p'>=0.05 local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "*"
		if `p'<0.05 & `p'>=0.01 local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "**"
		if `p'<0.01  			local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t')) "***"
		*local pm_`var'_`type' : di %4.3f 2*ttail(e(df_r),abs(`t'))
		local bm_`var'_`type' : di %6.3f _b[treated]
	}
	
	* Store counts
	count if treated==1
	local nu_treated_`type'=r(N)
	count if treated==0
	local nu_control_`type'=r(N)
	count if treated==1 & matched==1
	local nm_treated_`type'=r(N)
	count if treated==0 & matched==1
	local nm_control_`type'=r(N)
}

texdoc init $table/BalanceTestHire.tex, replace force

	tex \begin{tabular}{lcccccccc} \toprule \toprule 
	tex & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) \\ \midrule
	tex & \multicolumn{4}{c}{High-quality mover} & \multicolumn{4}{c}{Low-quality mover} \\ \cmidrule(lr){2-5}\cmidrule(lr){6-9}
	tex & \multicolumn{2}{c}{Unmatched} & \multicolumn{2}{c}{Matched} & \multicolumn{2}{c}{Unmatched} & \multicolumn{2}{c}{Matched} \\ \cmidrule(lr){2-3}\cmidrule(lr){4-5}\cmidrule(lr){6-7}\cmidrule(lr){8-9}
	tex & Diff. & P-value & Diff. & P-value & Diff. & P-value & Diff. & P-value \\
	tex \midrule 
	foreach var in $covs {
		tex ${lbe_`var'} & `bu_`var'_better' & `pu_`var'_better' & `bm_`var'_better' & `pm_`var'_better' & `bu_`var'_worse' & `pu_`var'_worse' & `bm_`var'_worse' & `pm_`var'_worse' \\
	}
	tex \midrule
	tex N. treated & \multicolumn{2}{c}{`nu_treated_better'} & \multicolumn{2}{c}{`nm_treated_better'} & \multicolumn{2}{c}{`nu_treated_worse'} & \multicolumn{2}{c}{`nm_treated_worse'} \\
	tex N. control & \multicolumn{2}{c}{`nu_control_better'} & \multicolumn{2}{c}{`nm_control_better'} & \multicolumn{2}{c}{`nu_control_worse'} & \multicolumn{2}{c}{`nm_control_worse'} \\
	tex \bottomrule \bottomrule
	tex \end{tabular}

texdoc close
