clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle set symbol

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close
*log using "$log/Hire_DataPrep_Matching.txt", replace

* Change this if you want to work with sample or full data
local data=0
if `data'==1 local s "sample"
if `data'==0 local s "raw"

use "$data/`s'_veneto_all", clear
drop yr*
format matr_az %12.0f

* merge ALPHA and PHI into the data
merge m:1 cod_pgr matr_az using "$data/alpha_phi"
keep if _merge == 3                // fully merged
drop _merge                        
rename (alpha1 phi1) (alpha psi)   // use reghdfe estimation

* Peer effect
gen n=1
bysort matr_az anno: egen num_emp=sum(n)
bysort matr_az anno: egen totalpha = sum(alpha)
gen avg_alpha_others = (totalpha - alpha)/(num_emp-1)
drop if avg_alpha_others==.
drop n

* Quantile of average peer effect
sum avg_alpha_others, det
foreach i in 5 10 25 50 75 90 95 {
	gen p`i'=r(p`i')
}
gen group=1*(avg_alpha_others<p10)+2*(avg_alpha_others>=p10 & avg_alpha_others<p25) ///
	+3*(avg_alpha_others>=p25 & avg_alpha_others<p50)+4*(avg_alpha_others>=p50 & avg_alpha_others<p75) ///
	+5*(avg_alpha_others>=p75 & avg_alpha_others<p90)+6*(avg_alpha_others>=p90)
	
gen N=1
gen age_hire=age if ten==0
bys cod_pgr (anno): carryforward age_hire, replace
keep if age_hire>=24 & age_hire<=30
keep if ten>=0 & ten<=6
gen blue=work_type=="Blue-collar"
gen lrw_hat=lrw-psi
collapse lrw* (sum) N, by(ten blue group age_hire)

sort blue age_hire group ten
bys blue age_hire group (ten): gen d_lrw=lrw-lrw[1]
bys blue age_hire group (ten): gen d_lrw_hat=lrw_hat-lrw_hat[1]

save $data/wageevol.dta, replace

drop lrw lrw_hat
gen label="<P10" if group==1 & ten==6
replace label="P10-P25" if group==2 & ten==6
replace label="P25-P50" if group==3 & ten==6
replace label="P50-P75" if group==4 & ten==6
replace label="P75-P90" if group==5 & ten==6
replace label=">P90" if group==6 & ten==6

forvalues i=0/1 {
	two (connected d_lrw ten if group==1, lwidth(0.5)) ///
		(connected d_lrw ten if group==2, lwidth(0.5)) ///
		(connected d_lrw ten if group==3, lwidth(0.5)) ///
		(connected d_lrw ten if group==4, lwidth(0.5)) ///
		(connected d_lrw ten if group==5, lwidth(0.5)) ///
		(connected d_lrw ten if group==6, lwidth(0.5)) ///
		if blue==`i' & age_hire==25, xlabel(0(1)6, grid) ///
		xtitle("Tenure with the firm") ytitle("Log wage growth") ///
		yscale(range(0 0.4)) ylabel(0(0.1)0.4, format(%3.1f) angle(hor)) ///
		legend(order(6 ">P90" 5 "P75-P90" 4 "P50-P75" 3 "P25-P50" 2 "P10-P25" 1 "<P10") cols(1) ring(0) pos(11)) ///
		name(g`i', replace) xsize(4.8)
	graph export $graph/wageevol_blue`i'.pdf, replace
}

