clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"
glo orig	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/orig"

foreach type in hire leave {
use "$data/`type'_better_for_regression", replace
*use "$data/leave_better_for_regression", replace
drop if treated==0 
recode treated (1=2)
append using "$data/`type'_worse_for_regression"
*append using "$data/leave_worse_for_regression"

* Firm-level info
merge m:1 matr_az using "$orig/azien", keep(1 3) keepusing(cod_fis) nogen

preserve 
use "$data/AIDA_1995_2001", clear
sum
gen cod_fis = Codicefiscale
gen cod_fis_1digit = substr(cod_fis,1,1)
tab cod_fis_1digit  // 0 1 4 8 9
drop cod_fis_1digit
destring cod_fis, replace
gen anno = year
save temp1, replace
restore 

gen cod_fis_1digit = substr(cod_fis,1,1)
gen cod_fis_merge = (cod_fis_1digit == "0" | cod_fis_1digit == "1" |  ///
					 cod_fis_1digit == "4" | cod_fis_1digit == "8" |  ///
					 cod_fis_1digit == "9") 
replace cod_fis	= "" if cod_fis_merge == 0
drop cod_fis_1digit cod_fis_merge
destring cod_fis, replace

merge m:1 cod_fis anno using "temp1.dta", keep(1 3) nogen ///
		  keepusing(ricavi val_added attivo reddito_op reddito_netto ROS ROA)
erase temp1.dta

bys matr_az anno: gen N=_N
gen lspw=log(ricavi/N)
gen lvapw=log(val_added/N)

drop if mover == 1
drop if k<=-3

gen treat2=treated>0

foreach var in s va {
	areg l`var'pw ib4.t##i.treat2 i.anno if matched==1 & inlist(treated,0,1) [aw=N], cluster(matr_az) absorb(matr_az)
	estimates store `var'w
	areg l`var'pw ib4.t##i.treat2 i.anno if matched==1 & inlist(treated,0,2) [aw=N], cluster(matr_az) absorb(matr_az)
	estimates store `var'b

	coefplot ///
		(`var'w, offset(0) label("low-quality worker") color(edkblue) lwidth(0.5) ciopts(recast(rcap) lwidth(0.5))) ///
		(`var'b, offset(0) label("high-quality worker") color(cranberry) ms(S) lwidth(0.5) ciopts(recast(rcap) lwidth(0.5) lpattern(dash))), ///
		keep(*.t#1.treat2) vert omitted baselevels xline(2.5, lc(black) lp(dash)) yline(0, lc(black)) ///
		xlabel(1 "-2" 2 "-1" 3 "0" 4 "1" 5 "2" 6 "3") recast(connected) ///
		ylabel(, format(%3.1f) angle(hor)) ytitle("Event-study coefficients") name(`type'_`var', replace)
	graph export $graph/ExogEventStudyReg_`var'_`type'.pdf, replace
}
/*
preserve
	collapse lvapw lspw [aw=N] if matched==1, by(treated k)
	drop if k<=-3
	two (connected lvapw lspw k if treated==0, ms(O Oh) color(dknavy orange) lp(solid solid)) ///
		(connected lvapw lspw k if treated==1, ms(S Sh) color(dknavy orange) lp(dash dash)) ///
		(connected lvapw lspw k if treated==2, ms(T Th) color(dknavy orange) lp(dash_dot dash_dot)), ///
		xlabel(-2(1)3) legend(order(1 "Log VA/empl similar" 2 "Log sales/empl similar" ///
		3 "Log VA/empl better" 4 "Log sales/empl better" 5 "Log VA/empl worse" 6 "Log sales/empl worse")) ///
		yti("Log VA/empl, Log sales/empl") name(`type', replace) ///
		xti("Time to event (Years)") ylabel(, format(%3.1f) angle(hor)) xline(0)
	graph export $graph/ExogEventStudy_`type'.pdf, replace
restore
*/

}
