

clear all
set more off
cd "X:\coworker\do files"

global sample "raw"          // <-- Pick the data to be used "sample" or "raw"
global format "xls, excel"   // <-- Choose reporting formate  "tex, tex(frag)"
local sample "$sample"


***********************************
**** EXOGENOUS MOBILITY CHECKS ****
***********************************

use "../data/coworker_akm_$sample", clear

* Generate new ids
egen id_worker=group(cod_pgr)
egen id_firm=group(matr_az)

***************************** CHECK 1 ******************************************
* Preserve data for later
*preserve
* Quartiles of firm fixed effects:
egen auxrank = rank(psi), unique
bys psi: egen tiedrank = mean(auxrank)
qui sum psi
glo length=r(N)
gen quartile_fe = ceil(4*tiedrank/$length)
drop auxrank tiedrank

gen mobility=0
sort id_worker anno
* I compute year-to-year mobility (hence gaps are not considered as mobility). 
replace mobility=1 if (id_worker[_n]==id_worker[_n-1])&(id_worker[_n]==id_worker[_n-2])& ///
	(id_worker[_n]==id_worker[_n+1])&(id_worker[_n]==id_worker[_n+2])& ///
	(id_firm[_n]!=id_firm[_n-1])&(id_firm[_n]!=id_firm[_n-2])&(id_firm[_n-1]==id_firm[_n-2])& ///
	(id_firm[_n]==id_firm[_n+1])&(id_firm[_n]==id_firm[_n+2])&(id_firm[_n+1]==id_firm[_n+2])& ///
	(anno[_n]==anno[_n-1]+1)&(anno[_n]==anno[_n-2]+2)&(anno[_n]==anno[_n+1]-1)&(anno[_n]==anno[_n+2]-2)

* Avoid overlaps in mobility
sort id_worker anno
by id_worker: drop if mobility[_n]==1 & mobility[_n+1]==1
by id_worker: drop if mobility[_n]==1 & mobility[_n+2]==1
by id_worker: drop if mobility[_n]==1 & mobility[_n+3]==1

* Identify years relative to year of job change
gen first_year = 0 if mobility==1
sort id_worker anno
by id_worker: replace first_year = -2 if (mobility[_n]==0 & mobility[_n+1]==0 & mobility[_n+2]==1) ///
										&(anno[_n]-anno[_n+2]==-2) ///
										&(id_firm[_n]==id_firm[_n+1] & id_firm[_n+2]==id_firm[_n+3] & id_firm[_n+3]==id_firm[_n+4])
by id_worker: replace first_year = -1 if (mobility[_n]==0 & mobility[_n+1]==1) ///
										&(anno[_n]-anno[_n+1]==-1) ///
										&(id_firm[_n]==id_firm[_n-1] & id_firm[_n+1]==id_firm[_n+2] & id_firm[_n+2]==id_firm[_n+3])
by id_worker: replace first_year = +1 if (mobility[_n-1]==1 & mobility[_n]==0) ///
										&(anno[_n]-anno[_n-1]==1) ///
										&(id_firm[_n-1]==id_firm[_n] & id_firm[_n]==id_firm[_n+1] & id_firm[_n-2]==id_firm[_n-3])
* assert that we have only multiples of 4
drop if first_year==.
bys id_worker: gen N=_N 
assert N==4|N==8|N==12|N==16|N==20|N==24
drop N

* Identify movements across firm effects quartiles at the year of job change
sort id_worker first_year
gen mov=.
forval i=1/4 {
	forval j=1/4 {
		replace mov=`i'`j' if first_year==0 & quartile[_n-1]==`i' & quartile[_n]==`j'
		}
	}

sort id_worker anno
by id_worker: gen n=_n
replace n=1 if n<=4
replace n=2 if n>4&n<=8
replace n=3 if n>8&n<=12
replace n=4 if n>12&n<=16
replace n=5 if n>16&n<=20
replace n=6 if n>20&n<=24
egen idwm=group(id_worker n)
bys idwm: egen movement=max(mov)
collapse (mean) meanwage=ln_wwage (count) frequency=id_worker, by(movement first_year)

* Color and labels 
colorpalette "rgb 0 114 178" gs12 "rgb 213 94 0", ipolate(8) 
grstyle init
grstyle set color `r(p)'
gen x=movement if first_year==1
recode x (21=.) (22=.) (23=.) (24=.) (31=.) (32=.) (33=.) (34=.)
label define movelab 11 "1-to-1" 12 "1-to-2" 13 "1-to-3" 14 "1-to-4" 41 "4-to-1" 42 "4-to-2" 43 "4-to-3" 44 "4-to-4", replace
label values x movelab 

* Figure 1: mean wages over time by origin-destination firm effect quartile
twoway (connected meanwage first_year if movement==11, lp(shortdash) m(D)) ///
	 (connected meanwage first_year if movement==12, lp(shortdash) m(S)) ///
	 (connected meanwage first_year if movement==13, lp(shortdash) m(O)) ///
	 (connected meanwage first_year if movement==14, lp(shortdash) m(T)) ///
	 (connected meanwage first_year if movement==41, m(T)) ///
	 (connected meanwage first_year if movement==42, m(S)) ///
	 (connected meanwage first_year if movement==43, m(O)) ///
	 (connected meanwage first_year if movement==44, m(D)) ///
	 (scatter meanwage first_year if !missing(x), ms(none) mlab(x) mlabgap(*3) mlabcolor(black)), ///
	 legend(off) xscale(r(-2.2(.2)1.2)) ///
	 graphregion(c(white)) ytitle("Mean Log Real Daily Wage") ///
	 xtitle("Relative Years (Year of job change = 0)") 
graph export "../results/graph/em_moves.pdf", replace

* Figure 2: mean wages over time by origin-dest fe quartile for movements within same quartile (1-1,2-2,3-3,4-4)	
drop x
gen x=movement if first_year==1 & (movement==11 | movement==22 | movement==33 | movement==44)
label define movelab 11 "1-to-1" 22 "2-to-2" 33 "3-to-3" 44 "4-to-4", replace
label value x movelab

twoway (connected meanwage first_year if movement==11, m(D)) ///
	 (connected meanwage first_year if movement==22, m(O)) ///
	 (connected meanwage first_year if movement==33, m(T)) ///
	 (connected meanwage first_year if movement==44, m(S)) ///
	 (scatter meanwage first_year if !missing(x), ms(none) mlab(x) mlabgap(*3) mlabcolor(black)), ///
	 legend(off) xscale(r(-2.2(.2)1.2)) ///
	 graphregion(c(white)) ytitle("Mean Log Real Daily Wage") ///
	 xtitle("Relative Years (Year of job change = 0)") 
graph export "../results/graph/em_same_quart.pdf", replace 

drop x

***************************** CHECK 2 ******************************************
 
* Check simmetry of opposite moves (i.e. q1-q2 should be roughly equal to q2-q1	in magnitude, q1-q3 to q3-q1, and so on...)
* tostring first_year is better for reshape...
tostring first_year, replace
replace first_year="minus2" if first_year=="-2"
replace first_year="minus1" if first_year=="-1"
replace first_year="plus1" if first_year=="1"
reshape wide meanwage frequency, i(movement) j(first_year) string

order movement meanwageminus2 meanwageminus1 meanwage0 meanwageplus1 
drop frequencyminus1 frequencyminus2 frequencyplus1 
* raw difference between mean wages 1 year after the move wrt 2 years before
gen raw = meanwageplus1-meanwageminus2

tostring movement, gen(movstr)
gen qorigin = substr(movstr,1,1)
gen qend=substr(movstr,2,1)
destring qorigin qend, replace
* adjustment constants
forval x=1/4 {
	sum raw if movement==`x'`x'
	gen raw`x'`x' = r(mean)
	} 
* adjusted wage change
gen adj=.
replace adj = raw - raw11 if qorigin==1 
replace adj = raw - raw22 if qorigin==2 
replace adj = raw - raw33 if qorigin==3 
replace adj = raw - raw44 if qorigin==4 

* Export file to excel
export excel movement meanwageminus2 meanwageminus1 meanwage0 meanwageplus1 ///
	frequency raw adj using "../results/exogenous_mobility.xlsx",  ///
	sheet("movers") firstrow(variables) sheetreplace

order movement frequency
drop frequency
drop if movement==11 | movement==22 | movement==33 | movement==44
keep movement qorigin qend raw adj

* Create two axes, one for upward movements and one for downward movements
* 1 = x axis (upward)		2 = y axis (downward)
gen axis = 1 if movement==12 | movement==13 | movement==14 | movement==34 | movement==23 | movement==24
replace axis = 2 if movement==21 | movement==31 | movement==41 | movement==43 | movement==32 | movement==42

drop qorigin qend

gen point="Q1-Q2, Q2-Q1" if movement==12 | movement==21
replace point="Q1-Q3, Q3-Q1" if movement==13 | movement==31
replace point="Q1-Q4, Q4-Q1" if movement==14 | movement==41
replace point="Q2-Q3, Q3-Q2" if movement==23 | movement==32
replace point="Q2-Q4, Q4-Q2" if movement==24 | movement==42
replace point="Q3-Q4, Q4-Q3" if movement==34 | movement==43

reshape wide raw adj movement, i(point) j(axis) 
gen pos=2
replace pos=6 if movement1==14

* Figure: plot downward moves against upward moves, they should cluster around 45° line
twoway (scatter adj2 adj1, m(S) mlw(thin) msiz(medlarge) mlc(black) mlabel(point) mlabvposition(pos) mlabgap(*2.5)) ///
	 (function y=-x, range(0 .5) lc(black) lp(shortdash)), graphregion(c(white)) ///
	 ytitle("{&Delta} Log Real Daily Wage For Downward Movers") ///
	 xtitle("{&Delta} Log Real Daily Wage For Upward Movers") legend(off) 
graph export "../results/graph/em_simmetry.pdf", replace 

***************************** CHECK 3 ******************************************

* Get back to original data
use "../data/coworker_akm_$sample", clear

* Generate deciles of person and firm effects
egen auxrank = rank(psi), unique
bys psi: egen tiedrank = mean(auxrank)
qui sum psi
glo length=r(N)
gen fedec = ceil(10*tiedrank/$length)
drop auxrank tiedrank

egen auxrank = rank(alpha), unique
bys alpha: egen tiedrank = mean(auxrank)
qui sum alpha
glo length=r(N)
gen pedec = ceil(10*tiedrank/$length)
drop auxrank tiedrank

* Compute joint distribution of firm and person effects and mean residuals across deciles of pe and fe
matrix distr = J(10,10,.)
matrix res = J(10,10,.)
forval i=1/10 {
	forval j=1/10 {
		qui count if pedec==`i' & fedec==`j'
		matrix distr[`i',`j']=r(N)/_N
		qui sum res if pedec==`i' & fedec==`j'
		matrix res[`i',`j']=r(mean)
		}
	}
set scheme s2color
drop _all
* Rows are deciles of person effects, columns are deciles of firm effects
svmat distr
export excel using "../results/exogenous_mobility.xlsx", sheet("joint_distr") firstrow(variables) sheetreplace
* Graph: joint distribution of worker and firm effects
gen pedec=_n
reshape long distr, i(pedec) j(fedec)
sort fedec pedec
order fedec pedec
gen n=_n
tw (bar distr n if fedec==1, lc(black) ls(grid)) (bar distr n if fedec==2, lc(black) ls(grid)) ///
	(bar distr n if fedec==3, lc(black) ls(grid)) (bar distr n if fedec==4, lc(black) ls(grid)) ///
	(bar distr n if fedec==5, lc(black) ls(grid)) (bar distr n if fedec==6, lc(black) ls(grid)) ///
	(bar distr n if fedec==7, lc(black) ls(grid)) (bar distr n if fedec==8, lc(black) ls(grid)) ///
	(bar distr n if fedec==9, lc(black) ls(grid)) (bar distr n if fedec==10, lc(black) ls(grid)), ///
	xlabel(5 "1" 15 "2" 25 "3" 35 "4" 45 "5" 55 "6" 65 "7" 75 "8" 85 "9" 95 "10") xti(Firm effect decile) ///
	yti(Frequency) legend(off) name(distr, replace) graphregion(c(white))
graph export "../results/graph/em_joint_distr.pdf", replace 
* Graph: mean residuals by worker and firm effects deciles
drop _all
svmat res
export excel using "exogenous_mobility.xlsx", sheet("residuals") firstrow(variables) sheetreplace
gen pedec=_n
reshape long res, i(pedec) j(fedec)
sort fedec pedec
order fedec pedec
gen n=_n
tw (bar res n if fedec==1, lc(black) ls(grid)) (bar res n if fedec==2, lc(black) ls(grid)) ///
	(bar res n if fedec==3, lc(black) ls(grid)) (bar res n if fedec==4, lc(black) ls(grid)) ///
	(bar res n if fedec==5, lc(black) ls(grid)) (bar res n if fedec==6, lc(black) ls(grid)) ///
	(bar res n if fedec==7, lc(black) ls(grid)) (bar res n if fedec==8, lc(black) ls(grid)) ///
	(bar res n if fedec==9, lc(black) ls(grid)) (bar res n if fedec==10, lc(black) ls(grid)), ///
	xlabel(5 "1" 15 "2" 25 "3" 35 "4" 45 "5" 55 "6" 65 "7" 75 "8" 85 "9" 95 "10") xti(Firm effect decile) ///
	yti(Frequency) legend(off) name(res, replace) graphregion(c(white))
graph export "../results/graph/em_res.pdf", replace 

