clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close
log using "$log/Leave_Regs.txt", replace

********************************************************************************
* ES Regression on coworkers only [Main]
********************************************************************************
local data  "better worse"  

foreach sample of local data {

use "$data/leave_`sample'_for_regression", replace
gen post=k>=0

drop if mover == 1

* Store DD coefficients
areg lrw i.post##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
global dd_`sample'   : disp %4.3f  _b[1.post#1.treated]
global sedd_`sample' : disp %4.3f _se[1.post#1.treated]

* Event study
areg lrw ib4.t##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
mat coef_up=( _b[1.t#1.treated],_b[2.t#1.treated],_b[3.t#1.treated],_b[4.t#1.treated],_b[5.t#1.treated],_b[6.t#1.treated],_b[7.t#1.treated],_b[8.t#1.treated] \ _se[1.t#1.treated],_se[2.t#1.treated],_se[3.t#1.treated],_se[4.t#1.treated],_se[5.t#1.treated],_se[6.t#1.treated],_se[7.t#1.treated],_se[8.t#1.treated] )
mat coef_up=coef_up'
mat li coef_up

tab k treated if e(sample) == 1
bys treat: distinct matr_az if matched==1

drop _all
svmat coef_up
rename (coef_up1 coef_up2) (b se)
gen ul=b+1.96*se
gen ll=b-1.96*se

foreach x of varlist _all {
	rename `x' `x'_`sample'
}

tempfile `sample'_graph
save "``sample'_graph'", replace


}

use "`better_graph'", clear
merge 1:1 _n using "`worse_graph'", nogen 
gen k=_n-5

twoway  (connected b_better b_worse k, ms(O S) color(edkblue cranberry) lw(.5 .5)) ///
		(rcap ul_better ll_better k, lc(edkblue) lw(.5)) (rcap ul_worse ll_worse k, lc(cranberry) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		legend(order(1 "high-quality worker" 2 "low-quality worker") rows(1)) ///
		ylab(-.03(.01).04,angle(horizontal) format(%3.2f)) ysc(r(-0.035 0.04)) ///
		title("{bf:Difference-in-differences coef.}" "high-quality = ${dd_better} (${sedd_better})" ///
		"low-quality = ${dd_worse} (${sedd_worse})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Leave_EventStudy.pdf", replace



********************************************************************************
* ES Regression on PEERS and NON-PEERS [subgroups]
********************************************************************************

local data "better worse"  
foreach sample of local data {

use "$data/leave_`sample'_for_regression", replace
gen post=k>=0

egen peer = group(matr_az work_type)
gen peer_mover_miss = peer if mover == 1
bysort matr_az: egen peer_mover = mean(peer_mover_miss)

forvalues subgroup = 1/2 {

	preserve 
	
	if `subgroup' == 1 {
		keep if peer_mover == peer
		local name "peers"
	}
	if `subgroup' == 2 {
		keep if peer_mover != peer
		local name "nonpeers"
	}
	drop if mover == 1
	
	* Store DD coefficients
	areg lrw i.post##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
	global dd`subgroup'_`sample'   : disp %4.3f  _b[1.post#1.treated]
	global sedd`subgroup'_`sample' : disp %4.3f _se[1.post#1.treated]

	* Event study
	areg lrw ib4.t##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
	mat coef=( _b[1.t#1.treated],_b[2.t#1.treated],_b[3.t#1.treated],_b[4.t#1.treated],_b[5.t#1.treated],_b[6.t#1.treated],_b[7.t#1.treated],_b[8.t#1.treated] \ _se[1.t#1.treated],_se[2.t#1.treated],_se[3.t#1.treated],_se[4.t#1.treated],_se[5.t#1.treated],_se[6.t#1.treated],_se[7.t#1.treated],_se[8.t#1.treated] )
	mat coef=coef'
	mat li coef

	tab k treated if e(sample) == 1

	* Subgroups Graphs
	
	drop _all
	svmat coef
	rename (coef1 coef2) (b se)
	gen ul=b+1.96*se
	gen ll=b-1.96*se
		
	foreach x of varlist _all {
		rename `x' `x'`subgroup'_`sample'
	} 
	
	tempfile `sample'_graph_`subgroup'
	save "``sample'_graph_`subgroup''", replace	
	
	restore 
	
}

}

clear 
use "`better_graph_1'", clear
merge 1:1 _n using "`better_graph_2'", nogen 
merge 1:1 _n using "`worse_graph_1'", nogen 
merge 1:1 _n using "`worse_graph_2'", nogen 
gen k=_n-5

twoway  (connected b1_better b2_better k, ms(O S) color(edkblue eltblue) lw(.5 .5))  /// 
		(rcap ul1_better ll1_better k, lc(edkblue) lw(.5)) ///
		(rcap ul2_better ll2_better k, lc(eltblue) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.04(0.02)0.06, angle(horizontal) format(%3.2f)) yscale(r(-0.04 0.06)) ///
		legend(order(1 "peer group" 2 "non-peer group") rows(1))  ///
		title("{bf:Difference-in-differences coef.}" "peer group = ${dd1_better} (${sedd1_better})" ///
		"non-peer group = ${dd2_better} (${sedd2_better})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Leave_EventStudyHigh_PeerVSNonPeer.pdf", replace

twoway  (connected b1_worse b2_worse k, ms(O S) color(cranberry cranberry*0.5) lw(.5 .5))  /// 
		(rcap ul1_worse ll1_worse k, lc(cranberry) lw(.5)) ///
		(rcap ul2_worse ll2_worse k, lc(cranberry*0.5) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.04(0.02)0.06, angle(horizontal) format(%3.2f)) yscale(r(-0.04 0.06)) ///
		legend(order(1 "peer group" 2 "non-peer group") rows(1)) ///
		title("{bf:Difference-in-differences coef.}" "peer group = ${dd1_worse} (${sedd1_worse})" ///
		"non-peer group = ${dd2_worse} (${sedd2_worse})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Leave_EventStudyLow_PeerVSNonPeer.pdf", replace





********************************************************************************
* ES Regression on HIGH-WAGE vs LOW-WAGE PEERS
********************************************************************************

local data "better worse"  
foreach sample of local data {

use "$data/leave_`sample'_for_regression", replace
gen post=k>=0

*use "$data/better_for_regression", replace
gen sector=substr(ateco91,1,1)

* High- and low-wage workers
preserve
	keep if k<0
	collapse (p50) median_wage=wwage, by(sector)
	keep sector median_wage
	tempfile median_wage
	save "`median_wage'"
restore
merge m:1 sector using "`median_wage'", nogen
gen highwage=wwage>median_wage

forvalues subgroup = 1/2 {

	preserve 
	
	if `subgroup' == 1 {
		keep if highwage == 1
		local name "highwage"
	}
	if `subgroup' == 2 {
		keep if highwage == 0
		local name "lowwage"
	}
	drop if mover == 1
	
	* Store DD coefficients
	areg lrw i.post##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
	global dd`subgroup'_`sample'   : disp %4.3f  _b[1.post#1.treated]
	global sedd`subgroup'_`sample' : disp %4.3f _se[1.post#1.treated]

	* Event study
	areg lrw ib4.t##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
	mat coef=( _b[1.t#1.treated],_b[2.t#1.treated],_b[3.t#1.treated],_b[4.t#1.treated],_b[5.t#1.treated],_b[6.t#1.treated],_b[7.t#1.treated],_b[8.t#1.treated] \ _se[1.t#1.treated],_se[2.t#1.treated],_se[3.t#1.treated],_se[4.t#1.treated],_se[5.t#1.treated],_se[6.t#1.treated],_se[7.t#1.treated],_se[8.t#1.treated] )
	mat coef=coef'
	mat li coef

	tab k treated if e(sample) == 1

	* Subgroups Graphs
	
	drop _all
	svmat coef
	rename (coef1 coef2) (b se)
	gen ul=b+1.96*se
	gen ll=b-1.96*se
		
	foreach x of varlist _all {
		rename `x' `x'`subgroup'_`sample'
	} 
	
	tempfile `sample'_graph_`subgroup'
	save "``sample'_graph_`subgroup''", replace	
	
	restore 
	
}

}

clear 
use "`better_graph_1'", clear
merge 1:1 _n using "`better_graph_2'", nogen 
merge 1:1 _n using "`worse_graph_1'", nogen 
merge 1:1 _n using "`worse_graph_2'", nogen 
gen k=_n-5

twoway  (connected b1_better b2_better k, ms(O S) color(edkblue eltblue) lw(.5 .5))  /// 
		(rcap ul1_better ll1_better k, lc(edkblue) lw(.5)) ///
		(rcap ul2_better ll2_better k, lc(eltblue) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.04(0.02)0.06, angle(horizontal) format(%3.2f)) yscale(r(-0.04 0.06)) ///
		legend(order(1 "high-wage workers" 2 "low-wage workers") rows(1))  ///
		title("{bf:Difference-in-differences coef.}" "high-wage = ${dd1_better} (${sedd1_better})" ///
		"low-wage = ${dd2_better} (${sedd2_better})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Leave_EventStudyHigh_HighWageVSLowWage.pdf", replace

twoway  (connected b1_worse b2_worse k, ms(O S) color(cranberry cranberry*0.5) lw(.5 .5))  /// 
		(rcap ul1_worse ll1_worse k, lc(cranberry) lw(.5)) ///
		(rcap ul2_worse ll2_worse k, lc(cranberry*0.5) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.04(0.02)0.06, angle(horizontal) format(%3.2f)) yscale(r(-0.04 0.06)) ///
		legend(order(1 "high-wage workers" 2 "low-wage workers") rows(1)) ///
		title("{bf:Difference-in-differences coef.}" "high-wage = ${dd1_worse} (${sedd1_worse})" ///
		"low-wage = ${dd2_worse} (${sedd2_worse})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Leave_EventStudyLow_HighWageVSLowWage.pdf", replace




********************************************************************************
* ES Regression on LARGE VS. SMALL FIRMS [for reply to Referee 3]
********************************************************************************

local data "better worse"  
foreach sample of local data {

use "$data/leave_`sample'_for_regression", replace
gen post=k>=0

* Large vs. small firms
preserve
drop if mover == 1
keep if k == 0
gen firm_size = 1
collapse (sum) firm_size, by(matr_az)
sum firm_size, det
gen median=r(p50)
gen above=firm_size>median
tempfile temp
save `temp'
restore

merge m:1 matr_az using `temp', nogen
sum median

forvalues subgroup = 1/2 {

	preserve 
	
	if `subgroup' == 1 {
		keep if above == 0
		local name "smallfirm"
	}
	if `subgroup' == 2 {
		keep if above == 1
		local name "largefirm"
	}
	drop if mover == 1
	
	* Store DD coefficients
	areg lrw i.post##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
	global dd`subgroup'_`sample'   : disp %4.3f  _b[1.post#1.treated]
	global sedd`subgroup'_`sample' : disp %4.3f _se[1.post#1.treated]

	* Event study
	areg lrw ib4.t##i.treated i.anno if matched==1, cluster(matr_az) absorb(matr_az)
	mat coef=( _b[1.t#1.treated],_b[2.t#1.treated],_b[3.t#1.treated],_b[4.t#1.treated],_b[5.t#1.treated],_b[6.t#1.treated],_b[7.t#1.treated],_b[8.t#1.treated] \ _se[1.t#1.treated],_se[2.t#1.treated],_se[3.t#1.treated],_se[4.t#1.treated],_se[5.t#1.treated],_se[6.t#1.treated],_se[7.t#1.treated],_se[8.t#1.treated] )
	mat coef=coef'
	mat li coef

	tab k treated if e(sample) == 1

	* Subgroups Graphs
	
	drop _all
	svmat coef
	rename (coef1 coef2) (b se)
	gen ul=b+1.96*se
	gen ll=b-1.96*se
		
	foreach x of varlist _all {
		rename `x' `x'`subgroup'_`sample'
	} 
	
	tempfile `sample'_graph_`subgroup'
	save "``sample'_graph_`subgroup''", replace	
	
	restore 
	
}

}

clear 
use "`better_graph_1'", clear
merge 1:1 _n using "`better_graph_2'", nogen 
merge 1:1 _n using "`worse_graph_1'", nogen 
merge 1:1 _n using "`worse_graph_2'", nogen 
gen k=_n-5

twoway  (connected b1_better b2_better k, ms(O S) color(edkblue eltblue) lw(.5 .5))  /// 
		(rcap ul1_better ll1_better k, lc(edkblue) lw(.5)) ///
		(rcap ul2_better ll2_better k, lc(eltblue) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.04(0.02)0.06, angle(horizontal) format(%3.2f)) yscale(r(-0.04 0.06)) ///
		legend(order(1 "below median firm-size" 2 "above median firm-size") rows(1))  ///
		title("{bf:Difference-in-differences coef.}" "below-median = ${dd1_better} (${sedd1_better})" ///
		"above-median = ${dd2_better} (${sedd2_better})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Leave_EventStudyHigh_SmallFirmVSLargeFirm.pdf", replace

twoway  (connected b1_worse b2_worse k, ms(O S) color(cranberry cranberry*0.5) lw(.5 .5))  /// 
		(rcap ul1_worse ll1_worse k, lc(cranberry) lw(.5)) ///
		(rcap ul2_worse ll2_worse k, lc(cranberry*0.5) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.04(0.02)0.06, angle(horizontal) format(%3.2f)) yscale(r(-0.04 0.06)) ///
		legend(order(1 "below median firm-size" 2 "above median firm-size") rows(1)) ///
		title("{bf:Difference-in-differences coef.}" "below-median = ${dd1_worse} (${sedd1_worse})" ///
		"above-median = ${dd2_worse} (${sedd2_worse})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Leave_EventStudyLow_SmallFirmVSLargeFirm.pdf", replace

log close
