clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close

********************************************************************************
* Hires
********************************************************************************
use "${data}/cont_treat_for_regression" , clear
drop if mover == 1
gen post=k>=0

* Generate regressors at time k=-3
glo contr "wwage psi alpha age female blue n firm_age"
foreach i in $contr {
	gen `i'_=`i' if k==-3
	bys matr_az: egen `i'_m3 = mean(`i'_)
	drop `i'_
}
foreach i in 4 2 1{ 
	gen wwage_=wwage if k==-`i'
	bys matr_az: egen wwage_m`i' = mean(wwage_)
	drop wwage_
}

* Winsorize outcome
forvalues i=-4/3 {
	qui sum lrw if k==`i', d
	replace lrw=r(p1) if lrw<r(p1) & k==`i'
	replace lrw=r(p99) if lrw>r(p99) & k==`i'
}

* Regressions
forvalues i=1/2{
	if `i'==1 local covs ""
	if `i'==2 local covs "c.wwage_m4 c.wwage_m3 c.wwage_m2 c.wwage_m1 c.alpha_m3 c.psi_m3 c.age_m3 c.female_m3 c.blue_m3 c.n_m3 c.firm_age_m3"
	
	areg lrw i.post##(c.alpha_movert0 `covs') i.anno, cluster(matr_az) absorb(matr_az)
	global dd_`i'   : disp %4.3f  _b[1.post#c.alpha_movert0]
	global sedd_`i' : disp %4.3f _se[1.post#c.alpha_movert0]
	
	areg lrw ib4.t##(c.alpha_movert0 `covs') i.anno, cluster(matr_az) absorb(matr_az)
	mat coef_`i'=( _b[1.t#c.alpha_movert0],_b[2.t#c.alpha_movert0],_b[3.t#c.alpha_movert0],_b[4.t#c.alpha_movert0],_b[5.t#c.alpha_movert0],_b[6.t#c.alpha_movert0],_b[7.t#c.alpha_movert0],_b[8.t#c.alpha_movert0] \ _se[1.t#c.alpha_movert0],_se[2.t#c.alpha_movert0],_se[3.t#c.alpha_movert0],_se[4.t#c.alpha_movert0],_se[5.t#c.alpha_movert0],_se[6.t#c.alpha_movert0],_se[7.t#c.alpha_movert0],_se[8.t#c.alpha_movert0] )
	mat coef_`i'=coef_`i''
	mat li coef_`i'
}

preserve
	drop _all
	svmat coef_1
	svmat coef_2
	rename (coef_11 coef_12 coef_21 coef_22) (b_1 se_1 b_2 se_2)
	gen ul_1=b_1+1.96*se_1
	gen ll_1=b_1-1.96*se_1
	gen ul_2=b_2+1.96*se_2
	gen ll_2=b_2-1.96*se_2
	gen k=_n-5

	two (connected b_1 b_2 k, ms(O S) color(gs2 gs11) lw(.5 .5)) ///
		(rcap ul_1 ll_1 k, lc(gs2) lw(.5)) (rcap ul_2 ll_2 k, lc(gs11) lw(.5) lp(dash)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		legend(order(1 "w/o controls" 2 "w/ controls")) ///
		ylab(,angle(horizontal) format(%3.2f)) ///
		title("{bf:Difference-in-differences coef.}" "w/o controls = ${dd_1} (${sedd_1})" ///
		"w/ controls = ${dd_2} (${sedd_2})", ring(0) pos(5) tstyle(body) justification(right))
	graph export "$graph/Hire_ContTreat_EventStudy.pdf", replace
	
	global dd1   = $dd_2
	global sedd1 = $sedd_2
	
	gen spec=1
	tempfile hire 
	save "`hire'"
	
restore


********************************************************************************
* Leaver
********************************************************************************
use "${data}/leave_cont_treat_for_regression" , clear
drop if mover == 1
gen post=k>=0

* Generate regressors at time k=-3
glo contr "wwage psi alpha age female blue n firm_age ricavi val_added"
foreach i in $contr {
	gen `i'_=`i' if k==-3
	bys matr_az: egen `i'_m3 = mean(`i'_)
	drop `i'_
}
foreach i in 4 2 1{ 
	gen wwage_=wwage if k==-`i'
	bys matr_az: egen wwage_m`i' = mean(wwage_)
	drop wwage_
}
reg c.wwage_m4 c.wwage_m3 c.wwage_m2 c.alpha_m3 c.psi_m3 c.age_m3 c.female_m3 c.blue_m3 c.n_m3 c.firm_age_m3 c.ricavi_m3 c.val_added_m3
keep if e(sample)

* Winsorize outcome
forvalues i=-4/3 {
	qui sum lrw if k==`i', d
	replace lrw=r(p1) if lrw<r(p1) & k==`i'
	replace lrw=r(p99) if lrw>r(p99) & k==`i'
}

* Regressions
forvalues i=1/2{
	if `i'==1 local covs ""
	if `i'==2 local covs "c.wwage_m4 c.wwage_m3 c.wwage_m2 c.wwage_m1 c.alpha_m3 c.psi_m3 c.age_m3 c.female_m3 c.blue_m3 c.n_m3 c.firm_age_m3"
	
	areg lrw i.post##(c.alpha_leavert0 `covs') i.anno, cluster(matr_az) absorb(matr_az)
	global dd_`i'   : disp %4.3f  _b[1.post#c.alpha_leavert0]
	global sedd_`i' : disp %4.3f _se[1.post#c.alpha_leavert0]
	
	areg lrw ib4.t##(c.alpha_leavert0 `covs') i.anno, cluster(matr_az) absorb(matr_az)
	mat coef_`i'=( _b[1.t#c.alpha_leavert0],_b[2.t#c.alpha_leavert0],_b[3.t#c.alpha_leavert0],_b[4.t#c.alpha_leavert0],_b[5.t#c.alpha_leavert0],_b[6.t#c.alpha_leavert0],_b[7.t#c.alpha_leavert0],_b[8.t#c.alpha_leavert0] \ _se[1.t#c.alpha_leavert0],_se[2.t#c.alpha_leavert0],_se[3.t#c.alpha_leavert0],_se[4.t#c.alpha_leavert0],_se[5.t#c.alpha_leavert0],_se[6.t#c.alpha_leavert0],_se[7.t#c.alpha_leavert0],_se[8.t#c.alpha_leavert0] )
	mat coef_`i'=coef_`i''
	mat li coef_`i'
}

preserve
	drop _all
	svmat coef_1
	svmat coef_2
	rename (coef_11 coef_12 coef_21 coef_22) (b_1 se_1 b_2 se_2)
	gen ul_1=b_1+1.96*se_1
	gen ll_1=b_1-1.96*se_1
	gen ul_2=b_2+1.96*se_2
	gen ll_2=b_2-1.96*se_2
	gen k=_n-5

	two (connected b_1 b_2 k, ms(O S) color(gs2 gs11) lw(.5 .5)) ///
		(rcap ul_1 ll_1 k, lc(gs2) lw(.5)) (rcap ul_2 ll_2 k, lc(gs11) lw(.5) lp(dash)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		legend(order(1 "w/o controls" 2 "w/ controls")) ///
		ylab(,angle(horizontal) format(%3.2f)) ///
		title("{bf:Difference-in-differences coef.}" "w/o controls = ${dd_1} (${sedd_1})" ///
		"w/ controls = ${dd_2} (${sedd_2})", ring(0) pos(5) tstyle(body) justification(right))
	graph export "$graph/Leave_ContTreat_EventStudy.pdf", replace
	
	global dd2   = $dd_2
	global sedd2 = $sedd_2
	
	gen spec=2
	tempfile leave 
	save "`leave'"
restore


********************************************************************************
* Movers
********************************************************************************
use "$data/better_matched_worker.dta", replace
gen todrop=treated==0
append using "$data/worse_matched_worker.dta"
drop if todrop==1	
drop t treated
gen post=k>=0
	
* tabulations
tab k 
	
* event dummies
sum k
gen t=k-r(min)+1
label define tlab 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5", replace
label values t tlab
sum t if k==-1
global i=r(mean)

drop *m3*
global contr "wwage weeks alphadec age female ten blue psi lnfirmsize"
foreach i in $contr {
	gen `i'_=`i' if k==-3
	bys cod_pgr: egen `i'_m3 = mean(`i'_)
	drop `i'_
}
foreach i in 4 2 1 { 
	gen wwage_=wwage if k==-`i'
	bys cod_pgr: egen wwage_m`i' = mean(wwage_)
	drop wwage_
}

* Avg alpha others
gen _avgalphaothers=avg_alpha_other if k==0
bys cod_pgr: egen avgalphaothers = mean(_avgalphaothers)
xi i.sector_str i.prov

* Winsorize outcome
forvalues i=-4/5 {
	qui sum lrw if k==`i', d
	replace lrw=r(p1) if lrw<r(p1) & k==`i'
	replace lrw=r(p99) if lrw>r(p99) & k==`i'
}

* Regressions
forvalues i=1/2{
	if `i'==1 local covs ""
	if `i'==2 local covs "c.wwage_m4 c.wwage_m3 c.wwage_m2 c.wwage_m1 c.alphadec_m3 c.psi_m3 c.age_m3 c.female_m3 c.blue_m3 c.ten_m3 c.lnfirmsize_m3"
	
	areg lrw i.post##(c.avgalphaothers `covs') i.anno _Isector_st* _Iprov*, cluster(cod_pgr) absorb(cod_pgr)
	global dd_`i'   : disp %4.3f  _b[1.post#c.avgalphaothers]
	global sedd_`i' : disp %4.3f _se[1.post#c.avgalphaothers]
	
	areg lrw ib4.t##(c.avgalphaothers `covs') i.anno _Isector_st* _Iprov*, cluster(cod_pgr) absorb(cod_pgr)
	mat coef_`i'=( _b[1.t#c.avgalphaothers],_b[2.t#c.avgalphaothers],_b[3.t#c.avgalphaothers],_b[4.t#c.avgalphaothers],_b[5.t#c.avgalphaothers],_b[6.t#c.avgalphaothers],_b[7.t#c.avgalphaothers],_b[8.t#c.avgalphaothers] \ _se[1.t#c.avgalphaothers],_se[2.t#c.avgalphaothers],_se[3.t#c.avgalphaothers],_se[4.t#c.avgalphaothers],_se[5.t#c.avgalphaothers],_se[6.t#c.avgalphaothers],_se[7.t#c.avgalphaothers],_se[8.t#c.avgalphaothers] )
	mat coef_`i'=coef_`i''
	mat li coef_`i'
}

preserve
	drop _all
	svmat coef_1
	svmat coef_2
	rename (coef_11 coef_12 coef_21 coef_22) (b_1 se_1 b_2 se_2)
	gen ul_1=b_1+1.96*se_1
	gen ll_1=b_1-1.96*se_1
	gen ul_2=b_2+1.96*se_2
	gen ll_2=b_2-1.96*se_2
	gen k=_n-5

	two (connected b_1 b_2 k, ms(O S) color(gs2 gs11) lw(.5 .5)) ///
		(rcap ul_1 ll_1 k, lc(gs2) lw(.5)) (rcap ul_2 ll_2 k, lc(gs11) lw(.5) lp(dash)),  ///   
		xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		legend(order(1 "w/o controls" 2 "w/ controls")) ///
		ylab(,angle(horizontal) format(%3.2f)) ///
		title("{bf:Difference-in-differences coef.}" "w/o controls = ${dd_1} (${sedd_1})" ///
		"w/ controls = ${dd_2} (${sedd_2})", ring(0) pos(5) tstyle(body) justification(right))
	graph export "$graph/Worker_ContTreat_EventStudy.pdf", replace
	
	global dd3   = $dd_2
	global sedd3 = $sedd_2
	
	gen spec=3
	tempfile mover 
	save "`mover'"

restore

use "`hire'", clear
append using "`leave'"
append using "`mover'"
keep b_2 ul_2 ll_2 k spec
rename (b_2 ul_2 ll_2) (b ul ll)
reshape wide b ul ll, i(k) j(spec)

two (connected b1 b2 b3 k, ms(O S T) color(blue*2.5 blue blue*0.5) lw(.5 .5 .5) lp(solid dash dash_dot)) ///
	(rcap ul1 ll1 k, lc(blue*2) lw(.5)) (rcap ul2 ll2 k, lc(blue) lw(.5)) (rcap ul3 ll3 k, lc(blue*0.5) lw(.5)),  ///   
	xlabel(-4(1)3)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
	yti("Event study coefficients") yline(0,lcolor(black)) ///
	legend(order(1 "Hire" 2 "Leaver" 3 "Mover") rows(1)) ///
	ylab(,angle(horizontal) format(%3.2f)) ///
	title("{bf:Difference-in-differences coef.}" "Mover = ${dd3} (${sedd3})" "Hire = ${dd1} (${sedd1})" ///
	"Leaver = ${dd2} (${sedd2})", ring(0) pos(11) tstyle(body) justification(left))
graph export "$graph/ContTreat_EventStudy_All.pdf", replace
	

