clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo orig	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/orig"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close
log using "$log/Worker_DataPrep_Matching.txt", replace

* Change this if you want to work with sample or full data
local sample=0
if `sample'==1 local s "sample"
if `sample'==0 local s "raw"

use "$data/`s'_veneto_all", clear
drop yr*
format matr_az %12.0f

* years of non-employment
bys cod_pgr (anno): gen aux=anno[_n]-anno[_n-1]
gen unempl=aux-1
recode unempl (.=0)
bys cod_pgr (anno): gen yrs_unempl=sum(unempl)
drop aux unempl

* merge ALPHA and PHI into the data
merge m:1 cod_pgr matr_az using "$data/alpha_phi"
keep if _merge == 3                // fully merged
drop _merge                        
rename (alpha1 phi1) (alpha psi)   // use reghdfe estimation

* Average coworker ability
gen n=1
bysort matr_az anno: egen num_emp=sum(n)
bysort matr_az anno: egen totalpha = sum(alpha)
gen avg_alpha_others = (totalpha - alpha)/(num_emp-1)
drop if avg_alpha_others==.
sort cod_pgr anno

********************************************************************************
* Finding the movers
********************************************************************************
xtset cod_pgr anno
gen mover=1 if cod_pgr==L.cod_pgr & matr_az!=L.matr_az
recode mover (.=0)
bys cod_pgr (anno): gen aux=sum(mover)
bys cod_pgr aux (anno): gen spell_length=_N 
drop if spell_length<4
drop aux

* Generate again the mover dummy (so to avoid having non-consecutive years)
drop mover
xtset cod_pgr anno
gen mover=1 if cod_pgr==L.cod_pgr & matr_az!=L.matr_az
recode mover (.=0)

* Keep only movers
bys cod_pgr: egen moverdum=max(mover)
keep if moverdum==1
drop moverdum

* Count number of mobility episodes for each mover
bys cod_pgr (anno): gen _nmob=sum(mover)
bys cod_pgr (anno): egen nmob=max(_nmob)
*drop if nmob>3 //Only one worker moves 4 times
keep if nmob==1

* Categories of mobility based on comparison of own ability with coworkers' ability
gen _betterpeers=1 if mover==1 & alpha<=avg_alpha_others-.1
gen _worsepeers=1 if mover==1 & alpha>avg_alpha_others+.1
gen _similpeers=1 if mover==1 & alpha>avg_alpha_others-.1 & alpha<=avg_alpha_others+.1

* Drop intersections 
drop if _betterpeers==1 & _similpeers==1
drop if _worsepeers==1  & _similpeers==1
drop if _betterpeers==1 & _worsepeers==1

foreach i in betterpeers worsepeers similpeers {
	bys cod_pgr: egen `i'=mean(_`i')
}
recode betterpeers similpeers worsepeers (.=0)
assert betterpeers+similpeers+worsepeers==1

/* Attempt to keep workers that move multiple times (using them both as treated and control): for the future (do not drop interserctions in this case)
bys cod_pgr (anno): carryforward _betterpeers _worsepeers _similpeers, replace
gen select=1 if betterpeers==1 & similpeers==1 & (_betterpeers==1 | _similpeers==1) */

* Identify year of mobility
gen _yearmob=anno if mover==1
bys cod_pgr (anno): carryforward _yearmob, replace
gsort cod_pgr -anno
by cod_pgr: carryforward _yearmob, replace

* Treatment dummies
gen treatbetter=1 if betterpeer==1
replace treatbetter=0 if similpeer==1
gen treatworse=1 if worsepeer==1
replace treatworse=0 if similpeer==1

* Event dummies
gen k=anno-_yearmob

* Covariates for matching
xtset cod_pgr anno
gen wagegrowth=D.wwage/L.wwage
gen blue=contract=="Operaio"
merge m:1 matr_az using "$orig/azien", keep(1 3) keepusing(prov) nogen

* Balanced sample
*keep if inrange(k,-5,10) //choose whether to trim or to bin
keep if inrange(k,-4,5) //choose whether to trim or to bin
*keep if inrange(k,-4,3) //choose whether to trim or to bin
qui sum k
local T=r(max)-r(min)+1
bys cod_pgr (k): gen T=_N
keep if T==`T'
gen sector_str = substr(ateco91, 1, 1)
replace sector_str = "X" if sector_str == "A" | sector_str == "B" | ///
                            sector_str == "C" | sector_str == "E" | ///
							sector_str == "L"

foreach var in psi lnfirmsize {
	gen _`var'dest=psi if k==0
	bys cod_pgr (k): egen `var'dest=mean(_`var'dest) 
}

*tempfile dataset
*save "`dataset'"
qui sum wwage, d
replace wwage=r(p1) if wwage<r(p1)
replace wwage=r(p99) if wwage>r(p99)
cap drop lrw
gen lrw=log(wwage)
foreach var in weeks lrw {
	*gen aux1=`var' if k==-5
	gen aux1=`var' if k==-4
	gen aux2=`var' if k==-3
	gen aux3=`var' if k==-2
	local k=4
	forvalues i=1/3 {
		bys cod_pgr: egen `var'_m`k'=mean(aux`i')
		local k=`k'-1
	}
	drop aux*
}
fastxtile alphadec=alpha, nq(10)
save "$data/worker_dataset.dta", replace

********************************************************************************
* Treatment group 1 and 2 (moving to better/worse peers)
********************************************************************************
foreach type in better worse {
	use "$data/worker_dataset.dta", clear
	rename treat`type' treated
	keep if treated!=.
	tempfile restr
	save "`restr'"

	* Matching
	keep if k==-3
	xi i.prov i.sector_str, noomit
	egen sector_num=group(ateco91)
	global covs "lrw_m4 lrw_m3 lrw_m2 weeks alphadec age female ten blue psi lnfirmsize"
	keep cod_pgr sector_num treated $covs _Isector_st* _Iprov*

	psmatch2 treated $covs  _Isector* _Iprov*, caliper(.001) noreplace neighbor(1)
	gen pair = _id if _treated==0 
	replace pair = _n1 if _treated==1
	bysort pair: egen paircount = count(pair)
	gen matched=paircount==2
	tab treated if matched

	* Balance check
	local n : list sizeof global(covs)
	mat b=J(`n',2,.)
	mat s=J(`n',2,.)
	local i=1
	foreach var in $covs {
		* Standardize dep. var.
		sum `var'
		gen svar=(`var'-r(mean))/r(sd)
		* Unmatched
		reg svar treated, cluster(sector_num)
		mat b[`i',1]=_b[treated]
		mat s[`i',1]=_se[treated]
		* Matched
		reg svar treated if matched==1, cluster(sector_num)
		mat b[`i',2]=_b[treated]
		mat s[`i',2]=_se[treated]
		drop svar
		local i=`i'+1
	}

	preserve

		drop _all
		svmat b
		svmat s
		rename (b1 b2 s1 s2) (bu bm su sm)
		gen ulu=bu+1.96*su
		gen llu=bu-1.96*su
		gen ulm=bm+1.96*sm
		gen llm=bm-1.96*sm
		gen n=_n
		gen nu=n+.1
		gen nm=n-.1
		keep if n <= `n'

		gen varname = _n
		tostring varname, replace
		replace varname = "Weekly wage -4"       	if varname == "1"
		replace varname = "Weekly wage -3"       	if varname == "2"
		replace varname = "Weekly wage -2"       	if varname == "3"
		replace varname = "Weeks worked"       		if varname == "4"
		replace varname = "Worker effect decile"    if varname == "5"
		replace varname = "Age"    			  		if varname == "6"
		replace varname = "Female"      	  		if varname == "7"
		replace varname = "Tenure"    		  		if varname == "8"
		replace varname = "Blue-collar" 	  		if varname == "9"
		replace varname = "AKM firm effect"   		if varname == "10"
		replace varname = "Log firm size"      		if varname == "11"

		labmask n, values(varname)	// * findit labmask
		
		twoway (scatter n bm, ms(none)) (scatter nm bm, ms(D) mc(edkblue)) (scatter nu bu, ms(O) mc(cranberry)) ///
			  (rcap ulm llm nm, hor lc(edkblue) lw(.5)) (rcap ulu llu nu, hor lc(cranberry) lp(dash) lw(.5)), ///
			  xline(0) graphregion(c(white)) yti("") ///
			  ylabel(1(1)11, valuelabel angle(horizontal) format(%20.0f)) legend(order(3 "Unmatched" 2 "Matched")) ///
			  xti("Standardized coefficient") name(balance_test_mA, replace) 
		graph export "$graph/Worker_BalanceTest_`type'.pdf", replace	
	
		graph twoway (scatter n bm, ms(o) xline(0)) (rcap ulm llm n, hor lc(black)) ///
			, graphregion(c(white)) yti("") ///
			  xscale(r(-1.1 1)) xlabel(-1(0.2)1) ///
			  ylabel(1(1)11, valuelabel angle(horizontal)) legend(off) ///
			  xti("Standardized coefficient") name(balance_test_m_`type', replace) 
		graph export "$graph/Worker_BalanceTestMatched_`type'.pdf", replace		  
		
		twoway (scatter n bu, ms(o) xline(0)) (rcap ulu llu n, hor lc(black)), ///
			graphregion(c(white)) ylabel(1(1)11, valuelabel angle(horizontal)) ///
			xscale(r(-1.1 1)) xlabel(-1(0.2)1) ///
			xti("Standardized coefficient")  legend(off) ///
			legend(off) name(balance_test_u_`type', replace) yti("")
		graph export "$graph/Worker_BalanceTestUnmatched_`type'.pdf", replace	
		
	restore

	* Density of pscore in treated and control firms
	twoway (kdensity _pscore if treated==1, lc(black) lw(.5)) (kdensity _pscore if treated==0, lc(black) lp(dash) lw(.5)), ///
		legend(order(1 "Treated workers" 2 "Control workers")) yti("Kernel density") xti("Propensity score") name(pscore_`type', replace)
	graph export "$graph/Worker_PscoreDensity_`type'.pdf", replace

	* Keep only relevant variables for matching and restrict to common support
	keep if _support==1
	keep cod_pgr _pscore _weight treated matched

	* Some tabulations
	tab treated  
	tab treated if _w!=.

	* Merge back to the original firm-year panel
	merge 1:m cod_pgr using "`restr'", keep(1 3)  
	sort cod_pgr anno
	save "$data/`type'_matched_worker.dta", replace
}

log close


