clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close
log using "$log/Worker_Regs.txt", replace


********************************************************************************
* Event-study regressions
********************************************************************************
foreach type in better worse {
	use "$data/`type'_matched_worker.dta", replace
	drop t
	gen post=k>=0
	
	gen _firmdest=matr_az if k==0
	bys cod_pgr: egen firmdest=mean(_firmdest)
	drop _firmdest
	
	* tabulations
	tab k treated
	tab k treated if matched
	
	* event dummies
	sum k
	gen t=k-r(min)+1
	label define tlab 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5", replace
	label values t tlab
	sum t if k==-1
	global i=r(mean)
	
	* descriptive graph (check parallel trends)
	preserve 
		collapse lrw if matched==1, by(k treated)
		two (connected lrw k if treated==0, mcolor(edkblue) lcolor(edkblue) lw(.5) lp(solid)) ///
			(connected lrw k if treated==1, mcolor(midblue) lcolor(midblue) lw(.5) lp(dash)), ///
			xlabel(-4(1)5) xline(-.5) legend(order(1 "similar peers" 2 "`type' peers")) ///
			ylabel(, angle(horizontal) format(%3.2f)) name(`type'_descr, replace) ///
			yti("Log real weekly wage") xti("Time to event (years)")
		graph export ${graph}/WorkerWagesMobility_Matched_`type'.pdf, replace
	restore
	
	* Store DD coefficients
	qui areg lrw i.post##i.treated i.anno if matched==1, cluster(cod_pgr) absorb(cod_pgr)
	global dd_`type'   : disp %4.3f  _b[1.post#1.treated]
	global sedd_`type' : disp %4.3f _se[1.post#1.treated]

	* Event study
	qui areg lrw ib${i}.t##i.treated i.anno if matched==1, cluster(cod_pgr) absorb(cod_pgr)
	mat coef=( _b[1.t#1.treated],_b[2.t#1.treated],_b[3.t#1.treated],_b[4.t#1.treated],_b[5.t#1.treated],_b[6.t#1.treated],_b[7.t#1.treated],_b[8.t#1.treated],_b[9.t#1.treated],_b[10.t#1.treated] \ _se[1.t#1.treated],_se[2.t#1.treated],_se[3.t#1.treated],_se[4.t#1.treated],_se[5.t#1.treated],_se[6.t#1.treated],_se[7.t#1.treated],_se[8.t#1.treated],_se[9.t#1.treated],_se[10.t#1.treated] )
	mat coef=coef'
	mat li coef
	
	drop _all
	svmat coef
	rename (coef1 coef2) (b se)
	gen ul=b+1.96*se
	gen ll=b-1.96*se

	foreach x of varlist _all {
		rename `x' `x'_`type'
	}

	tempfile `type'_graph
	save "``type'_graph'", replace
}

use "`better_graph'", clear
merge 1:1 _n using "`worse_graph'", nogen 
gen k=_n-5

twoway  (connected b_better b_worse k, ms(O S) color(edkblue cranberry) lw(.5 .5)) ///
		(rcap ul_better ll_better k, lc(edkblue) lw(.5)) (rcap ul_worse ll_worse k, lc(cranberry) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)5)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		legend(order(1 "high-quality peers" 2 "low-quality peers") rows(1)) ///
		ylab(-.02(.01).05,angle(horizontal) format(%3.2f)) ysc(r(-0.022 0.05)) ///
		title("{bf:Difference-in-differences coef.}" "high-quality = ${dd_better} (${sedd_better})" ///
		"low-quality = ${dd_worse} (${sedd_worse})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Worker_EventStudy.pdf", replace



********************************************************************************
* Event-study regressions - BLUE v WHITE-COLLAR WORKERS
********************************************************************************
local data "better worse"  
foreach sample of local data {

use "$data/`sample'_matched_worker.dta", replace
drop t
gen post=k>=0
gen _bluet0=blue if k==-1
bys cod_pgr: egen bluet0=mean(_bluet0)
drop _bluet0

* event dummies
sum k
gen t=k-r(min)+1
label define tlab 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5", replace
label values t tlab
sum t if k==-1
global i=r(mean)
	
forvalues subgroup = 1/2 {

	preserve 
	
	if `subgroup' == 1 {
		keep if bluet0 == 1
		local name "blue"
	}
	if `subgroup' == 2 {
		keep if bluet0 == 0
		local name "nonblue"
	}
	
	* Store DD coefficients
	areg lrw i.post##i.treated i.anno if matched==1, cluster(cod_pgr) absorb(cod_pgr)
	global dd`subgroup'_`sample'   : disp %4.3f  _b[1.post#1.treated]
	global sedd`subgroup'_`sample' : disp %4.3f _se[1.post#1.treated]

	* Event study
	areg lrw ib4.t##i.treated i.anno if matched==1, cluster(cod_pgr) absorb(cod_pgr)
	mat coef=( _b[1.t#1.treated],_b[2.t#1.treated],_b[3.t#1.treated],_b[4.t#1.treated],_b[5.t#1.treated],_b[6.t#1.treated],_b[7.t#1.treated],_b[8.t#1.treated],_b[9.t#1.treated],_b[10.t#1.treated] \ _se[1.t#1.treated],_se[2.t#1.treated],_se[3.t#1.treated],_se[4.t#1.treated],_se[5.t#1.treated],_se[6.t#1.treated],_se[7.t#1.treated],_se[8.t#1.treated],_se[9.t#1.treated],_se[10.t#1.treated] )
	mat coef=coef'
	mat li coef

	tab k treated if e(sample) == 1

	* Subgroups Graphs
	
	drop _all
	svmat coef
	rename (coef1 coef2) (b se)
	gen ul=b+1.96*se
	gen ll=b-1.96*se
		
	foreach x of varlist _all {
		rename `x' `x'`subgroup'_`sample'
	} 
	
	tempfile `sample'_graph_`subgroup'
	save "``sample'_graph_`subgroup''", replace	
	
	restore 
	
}

}

clear 
use "`better_graph_1'", clear
merge 1:1 _n using "`better_graph_2'", nogen 
merge 1:1 _n using "`worse_graph_1'", nogen 
merge 1:1 _n using "`worse_graph_2'", nogen 
gen k=_n-5

twoway  (connected b1_better b2_better k, ms(O S) color(edkblue eltblue) lw(.5 .5))  /// 
		(rcap ul1_better ll1_better k, lc(edkblue) lw(.5)) ///
		(rcap ul2_better ll2_better k, lc(eltblue) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)5)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.06(0.02)0.08, angle(horizontal) format(%3.2f)) yscale(range(-0.06 0.08)) ///
		legend(order(1 "blue-collar" 2 "white-collar") rows(1))  ///
		title("{bf:Difference-in-differences coef.}" "blue-collar = ${dd1_better} (${sedd1_better})" ///
		"white-collar = ${dd2_better} (${sedd2_better})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Worker_EventStudyHigh_BlueVSWhite.pdf", replace

twoway  (connected b1_worse b2_worse k, ms(O S) color(cranberry cranberry*0.5) lw(.5 .5))  /// 
		(rcap ul1_worse ll1_worse k, lc(cranberry) lw(.5)) ///
		(rcap ul2_worse ll2_worse k, lc(cranberry*0.5) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)5)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.06(0.02)0.08, angle(horizontal) format(%3.2f)) yscale(range(-0.06 0.08)) ///
		legend(order(1 "blue-collar" 2 "white-collar") rows(1)) ///
		title("{bf:Difference-in-differences coef.}" "blue-collar = ${dd1_worse} (${sedd1_worse})" ///
		"white-collar = ${dd2_worse} (${sedd2_worse})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Worker_EventStudyLow_BlueVSWhite.pdf", replace





********************************************************************************
* Event-study regressions - HIGH v LOW-WAGE WORKERS
********************************************************************************
*use ${data}/raw_veneto_all, clear
*gen sector_str = substr(ateco91, 1, 1)
*collapse (p50) median_wwage=wwage, by(sector_str anno)
*save ${data}/wage_by_sector.dta, replace

local data "better worse"  
foreach sample of local data {

use "$data/`sample'_matched_worker.dta", replace
drop t
gen post=k>=0
capture drop sector_str _merge
gen sector_str = substr(ateco91, 1, 1)
merge m:1 sector_str anno using ${data}/wage_by_sector.dta, keep(3) nogen
gen _highwage=wwage>median_wwage if k==-1
bys cod_pgr: egen highwage=mean(_highwage)

* event dummies
sum k
gen t=k-r(min)+1
label define tlab 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5", replace
label values t tlab
sum t if k==-1
global i=r(mean)
	
forvalues subgroup = 1/2 {

	preserve 
	
	if `subgroup' == 1 {
		keep if highwage == 1
	}
	if `subgroup' == 2 {
		keep if highwage == 0
	}
	
	* Store DD coefficients
	areg lrw i.post##i.treated i.anno if matched==1, cluster(cod_pgr) absorb(cod_pgr)
	global dd`subgroup'_`sample'   : disp %4.3f  _b[1.post#1.treated]
	global sedd`subgroup'_`sample' : disp %4.3f _se[1.post#1.treated]

	* Event study
	areg lrw ib4.t##i.treated i.anno if matched==1, cluster(cod_pgr) absorb(cod_pgr)
	mat coef=( _b[1.t#1.treated],_b[2.t#1.treated],_b[3.t#1.treated],_b[4.t#1.treated],_b[5.t#1.treated],_b[6.t#1.treated],_b[7.t#1.treated],_b[8.t#1.treated],_b[9.t#1.treated],_b[10.t#1.treated] \ _se[1.t#1.treated],_se[2.t#1.treated],_se[3.t#1.treated],_se[4.t#1.treated],_se[5.t#1.treated],_se[6.t#1.treated],_se[7.t#1.treated],_se[8.t#1.treated],_se[9.t#1.treated],_se[10.t#1.treated] )
	mat coef=coef'
	mat li coef

	tab k treated if e(sample) == 1

	* Subgroups Graphs
	
	drop _all
	svmat coef
	rename (coef1 coef2) (b se)
	gen ul=b+1.96*se
	gen ll=b-1.96*se
		
	foreach x of varlist _all {
		rename `x' `x'`subgroup'_`sample'
	} 
	
	tempfile `sample'_graph_`subgroup'
	save "``sample'_graph_`subgroup''", replace	
	
	restore 
	
}

}

clear 
use "`better_graph_1'", clear
merge 1:1 _n using "`better_graph_2'", nogen 
merge 1:1 _n using "`worse_graph_1'", nogen 
merge 1:1 _n using "`worse_graph_2'", nogen 
gen k=_n-5

twoway  (connected b1_better b2_better k, ms(O S) color(edkblue eltblue) lw(.5 .5))  /// 
		(rcap ul1_better ll1_better k, lc(edkblue) lw(.5)) ///
		(rcap ul2_better ll2_better k, lc(eltblue) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)5)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.06(0.02)0.08, angle(horizontal) format(%3.2f)) yscale(range(-0.06 0.08)) ///
		legend(order(1 "high-wage workers" 2 "low-wage workers") rows(1))  ///
		title("{bf:Difference-in-differences coef.}" "high-wage = ${dd1_better} (${sedd1_better})" ///
		"low-wage = ${dd2_better} (${sedd2_better})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Worker_EventStudyHigh_HighWageVSLowWage.pdf", replace

twoway  (connected b1_worse b2_worse k, ms(O S) color(cranberry cranberry*0.5) lw(.5 .5))  /// 
		(rcap ul1_worse ll1_worse k, lc(cranberry) lw(.5)) ///
		(rcap ul2_worse ll2_worse k, lc(cranberry*0.5) lp(dash) lw(.5)),  ///   
		xlabel(-4(1)5)  xti("Time to event (years)") xline(-0.5, lp(dash) lcolor(black)) /// 
		yti("Event study coefficients") yline(0,lcolor(black)) ///
		ylab(-0.06(0.02)0.08, angle(horizontal) format(%3.2f)) yscale(range(-0.06 0.08)) ///
		legend(order(1 "high-wage workers" 2 "low-wage workers") rows(1)) ///
		title("{bf:Difference-in-differences coef.}" "high-wage = ${dd1_worse} (${sedd1_worse})" ///
		"low-wage = ${dd2_worse} (${sedd2_worse})", ring(0) pos(5) tstyle(body) justification(right))
graph export "$graph/Worker_EventStudyLow_HighWageVSLowWage.pdf", replace


log close
