*----------------------------------------------------------------------------*
* Prepare Matlab data 
*----------------------------------------------------------------------------*

local sample "raw"     					 // choose sample
if "`sample'" == "sample" {
	global data "$data/sample"
}
use "$data/`sample'_veneto_all", clear 

*----------------------------------------------------------------------------*

*firmsize restricted 5000
drop ido lnfirmsize-yr20 young-t
drop contract_type hour_type contract anno_n age0 exp
rename (cod_pgr matr_az) (worker firmid)


* movers (who moved in the next five years)
xtset worker anno  
forvalues i = 0/5 {
	gen double firmid_f`i' = f`i'.firmid
	format firmid_f`i' %12.0g
}
forvalues j = 1/5 {
	local i = `j'-1 // prev year != this year  & desti firm is not missing (prev firm can be missing)
	gen move_f`j' = (firmid_f`i' != firmid_f`j' & firmid_f`j' != .)
}
egen mover = rowmax(move_f*)
sum mover 
disp "movers within the next five years = " r(mean)*100 "%"
drop firmid_*
drop move_*


*----------------------------------------------------------------------------*
global covariates "age2 ten ten2 ten10 age female mover"  // covariates	

forvalues h = 0/5 {	

	preserve
	
	* Get future wages
	gen  lrw_f`h' = f`h'.lrw 
	drop if lrw_f`h' == .
	drop lrw
	rename lrw_f`h' lrw 
	
	* New IDs
	gegen double idw = group(worker)
	gegen double idf = group(firmid)
	gegen double idt = group(anno)
	gegen double ido = group(work_type)          // blue or white
	gegen double ids = group(ateco91)
	gen   double idn = _n                        // double is important!	
	
	* cross-walk
	keep  lrw idw idt idf ido ids $covariates idn worker anno firmid firmsize
	if "`sample'" == "raw" {
		save "$data/crosswalk_veneto_w`h'", replace
	}

	
	* Matlab inputs
	keep  lrw idw idt idf ido ids $covariates idn 
	order lrw idw idt idf ido ids $covariates idn
	sum 
	
	* Prepare output	
	xtset idw idt
	export delimited using "$data/veneto_fs5000_w`h'.txt", replace
	
	restore 

}

