*-----------------------------------------------------------------------------*
* Basic cleaning from raw data
*-----------------------------------------------------------------------------*

* raw data merge 
use "$rawdata/anagr.dta", clear
merge 1:m cod_pgr using "$rawdata/contr.dta"
drop _merge 
merge m:1 matr_az using "$rawdata/azien.dta"
drop _merge 


* all firms in Veneto only 
gen istat_2001 = cod_com  
merge m:1 istat_2001 using "$rawdata/com_sll_2001"
keep if _merge == 3
gen veneto = (reg == 5)    // veneto
drop reg - _merge 


* keep from year 1982 to year 2001 - contract info missing
gen sampleperiod = (anno >= 1982 & anno <= 2001)   


* Basic demographics
gen age       = anno - anno_n
replace age   = . if age < 0 
gen female    = (sesso=="F") if sesso!="X" 


* Contract
replace qualif = subinstr(qualif," ","",.)
replace qualif = upper(qualif)
merge m:1 qualif using "$rawdata/Ricodifica_qualif"
drop if _merge == 2       // 0.17% not matched
drop _merge 


* Total working weeks/days per contract - Daily wage might not be accurate (!)
gen     weeks = sett_r if hour_type=="F"
replace weeks = sett_u if hour_type=="P"
replace weeks = . if weeks == 0 | weeks > 53  // 0.7% unreasonable weeks
gen     days = gior_r                 if hour_type=="F"
replace days = gior_r*(sett_u/sett_r) if hour_type=="P"
replace days = round(days)
replace days = . if  days == 0 | days > 365   // 21.5% (!) not accurate?


* Generate annual earnings and wages and job-specific wages
bys cod_pgr anno: egen tot_weeks    = sum(weeks)
bys cod_pgr anno: egen tot_earnings = sum(retrib03)
gen tot_wwage=tot_earnings/tot_weeks
gen wwage=retrib03/weeks


* Keep one observation per worker per year (main job: highest weeks/days/wage)
bys cod_pgr anno: egen maxweeks = max(weeks)
keep if maxweeks==weeks
bys cod_pgr anno: egen maxwage = max(retrib03)
keep if maxwage==retrib03
bys cod_pgr anno: gen n=_n   // Break ties
keep if n==1


* firm tenure 
preserve 
keep cod_pgr anno matr_az 
duplicates drop
sort cod_pgr matr_az  anno
bysort cod_pgr matr_az: gen tenure = _n-1
sort cod_pgr anno matr_az  
save "$data/temp_tenure", replace
restore 
merge m:1 cod_pgr anno matr_az using "$data/temp_tenure"
drop _merge
erase "$data/temp_tenure.dta"


* Additional variables
bysort cod_pgr: egen age0 = min(age)
xtset cod_pgr anno
gen exp = _n-1


* Restrictions:
tab veneto
keep if veneto == 1               // veneto only
keep if sampleperiod == 1         // 1982 - 2001
keep if inrange(age,16,65)        // age 16-65 (main labor force) - 0.6% dropped
drop if female == .               // drop gender = "X" 
drop if wwage  == . | wwage == 0  // drop missing wages 


* keep regresors
keep cod_pgr anno matr_az cod_com age-tenure anno_n age0 exp ateco91
