*-----------------------------------------------------------------------------*
* Create additional variables for analysis
*-----------------------------------------------------------------------------*

* New ids for firms and workers
egen idf=group(matr_az)
egen idw=group(cod_pgr)
sum idw idf

* restrict firm size
bysort idf anno: gen firmsize = _N
drop if firmsize < 2 
drop if firmsize > 5000

* Proxy for occupation
drop if ateco91 == "#N/D   "
egen ido = group(work_type ateco91)


* Control variables
*-------------------

* foreign resident dummy?

rename tenure ten
gen ten10=(ten>=10)
replace ten=0 if ten>=10
gen ten2=ten^2/100
gen age2=age^2/100
gen lnfirmsize=ln(firmsize)
tab anno, gen(yr)
gen lrw=ln(wwage)

gen young = (age<=35) 


* Basic sample restriction
*--------------------------

* more restrictions
keep if age >= 16 & age <= 65
drop if work_type == "Apprentice"
drop if hour_type == "P"

* drop missing
local keyvars "lnfirmsize ten ten2 ten10 age age2 yr2-yr20"
reg lrw `keyvars'
keep if e(sample) == 1   


* Name sectors
*--------------------------
gen sector = substr(ateco91, 1, 1)
gen     secname = "Argriculture" if sector == "A" | sector == "B" | sector == "C"
replace secname = "Manufacture"  if sector == "D"
replace secname = "Electricity"  if sector == "E"
replace secname = "Construction" if sector == "F"
replace secname = "Wholesale"    if sector == "G"
replace secname = "Hotel"  		 if sector == "H"
replace secname = "Transports"   if sector == "I"
replace secname = "Finance" 	 if sector == "J"
replace secname = "Services" 	 if sector == "K"
replace secname = "PublicAdmin"  if sector == "L"   // public?
replace secname = "Health"  	 if sector == "N"   // public?
replace secname = "DomesticWork" if sector == "O"   



* Peer group (firm x occupation)
*--------------------------------

egen peer = group(idf ido anno)

xtset idw anno 
gen l`i'peer = l`i'.peer

drop if l`i'peer == .
drop peer
rename l`i'peer peer

bysort peer: gen psize=_N
drop if psize<2
sum psize, de
bysort peer: gen tag=1 if _n==1
sum psize if tag==1, de
drop tag psize


* Largest connected set (at least two workers and largest connected)
*-----------------------

drop idw idf
egen idw = group(cod_pgr)
egen idf = group(matr_az)

local num_drop = 99
local ite = 0
while `num_drop' > 0 {

	local ite = `ite' + 1

	capture noisily a2group, individual(idw) unit(idf) groupvar(group)
	bysort group: gen grobs=_N
	egen maxobs=max(grobs)
	gen N=_N
	gen fracgr1=maxobs/N*100
	sum fracgr1
	keep if grobs==maxobs
	drop grobs maxobs N fracgr1 group

	bysort peer: gen psize = _N
	sum psize, detail
	bysort peer: gen tag=1 if _n==1
	sum psize if tag==1, detail
	drop tag
	drop if psize <2              // no observations dropped
	local num_drop = r(N_drop)
	drop psize

}
display "total iteration = " `ite'

* Run AKM 
local controls "lnfirmsize ten ten2 ten10 age2 yr2-yr20"
a2reg ln_wwage `controls', individual(idw) unit(idf) indeffect(alpha) uniteffect(psi) xb(xb) resid(res)
save "$data/alpha_psi", replace


* final sample 
save "$data/raw_veneto_all", replace  


* Get one percent sample
*--------------------------

preserve 
keep idw
duplicates drop 
sample 1
save "idw_1pc", replace
restore
merge m:1 idw using idw_1pc 
keep if _merge == 3
drop _merge 
erase "idw_1pc.dta"

save "$data/sample_veneto_all", replace



