*----------------------------------------------------------------------------*
* Load text data to Stata format
*----------------------------------------------------------------------------*

local covariates "age2 ten ten2 ten10 age female mover"  // covariates	
local id "idw idt idf ido ids"
local fe "alpha fofe otfe ftfe"
forvalues i = 0/5 {   
	
	import delimited "$datgr/data_regheter_w`i'.txt", clear
	rename (v1-v19) (pm `fe' lrw `id' `covariates' idn)
	
	merge 1:1 idn using "$data/crosswalk_veneto_w`i'"
	keep if _merge == 3
	drop _merge 
	
	rename  (worker firmid) (cod_pgr matr_az)
	merge 1:1 cod_pgr anno using  "$data/raw_veneto_all"
	keep if _merge == 3
	drop _merge 
	drop anno_n contract-t

	gen istat_2001 = cod_com  
	merge m:1 istat_2001 using "$rawdata/com_sll_2001"
	drop if _merge == 2
	gen llm_id   = sll_2001
	gen llm_name = den_sll_2001
	drop cod_com istat_2001 - _merge 
	
	save "$datgr/temp_hetergraph_w`i'", replace

}


*----------------------------------------------------------------------------*
* Re-define mover/stayer
*----------------------------------------------------------------------------*

use "$datgr/temp_hetergraph_w0", clear

xtset cod_pgr anno
forvalues i = 1/5 {
    gen double l`i'matr = L`i'.matr_az  // double is important
	gen double f`i'matr = F`i'.matr_az
	format l`i'matr %12.0g
	format f`i'matr %12.0g
}

* relabel 
forvalues i = 10(-1)6 {
	local j = `i' - 5
	rename f`j'matr f`i'
}
gen double f5 = matr_az
format f5 %12.0g
rename l1matr f4
rename l2matr f3
rename l3matr f2
rename l4matr f1
rename l5matr f0

order cod_pgr matr_az anno f0 f1 f2 f3 f4 f5 f6 f7 f8 f9 f10
keep  cod_pgr matr_az anno f0 f1 f2 f3 f4 f5 f6 f7 f8 f9 f10
save "temp_mover", replace


* Define movers
forvalues k = 10(-1)5 {
	local m = `k' - 5
	
	use "temp_mover", clear
	keep if f`k' != .		
	
	forvalues i = 1/5 {
		local j = `k' - `i'
		gen move`i' = f`k' != f`i' & f`i' != . 
	}
	forvalues i = 1/5 {
		local j = `k' - `i'
		gen stay`i' = f`k' == f`i' & f`i' != . 
	}
	egen mover_f`m' = rowmax(move1-move5)
	egen _stayer_f`m' = rowtotal(stay1-stay5)
	gen  stayer_f`m' = _stayer_f`m' == 5
	
	keep cod_pgr anno mover_f`m' stayer_f`m' matr_az
	save "$data/movestay_f`m'", replace
	
}
erase "temp_mover.dta"


*----------------------------------------------------------------------------*
* Merge mover/stayer
*----------------------------------------------------------------------------*

forvalues i = 0/5 {
	
	use "$datgr/temp_hetergraph_w`i'", clear
	drop mover
	
	merge 1:1 cod_pgr anno using  "$data/movestay_f`i'"
	drop if _merge == 2   // mover/stayer has attenuation due to unemployment
	drop _merge   
	rename mover_f`i'   mover 
	rename stayer_f`i'  stay	
	
	order `id' `fe' `covariates' stay idn 
	erase "$datgr/temp_hetergraph_w`i'.dta"
	save "$datgr/data_hetergraph_w`i'", replace
		
}


*-----------------------------------------------------------------------------
* Collect all
*-----------------------------------------------------------------------------

global controls "age age2 ten ten2 ten10 alpha fofe otfe ftfe"

*-----------------------------------------------------------------------------
* Heterogeneous regressions
*-----------------------------------------------------------------------------

mat ms_est = J(6,2,0)
mat ms_se  = J(6,2,0)
mat ms_obs = J(6,2,0)

mat fsize1_est = J(6,3,0)
mat fsize1_se  = J(6,3,0)
mat fsize1_obs = J(6,3,0)
mat fsize2_est = J(6,3,0)
mat fsize2_se  = J(6,3,0)
mat fsize2_obs = J(6,3,0)
mat fsize3_est = J(6,3,0)
mat fsize3_se  = J(6,3,0)
mat fsize3_obs = J(6,3,0)

mat psize1_est = J(6,3,0)
mat psize1_se  = J(6,3,0)
mat psize1_obs = J(6,3,0)
mat psize2_est = J(6,3,0)
mat psize2_se  = J(6,3,0)
mat psize2_obs = J(6,3,0)
mat psize3_est = J(6,3,0)
mat psize3_se  = J(6,3,0)
mat psize3_obs = J(6,3,0)

mat ten_est = J(6,3,0)
mat ten_se  = J(6,3,0)
mat ten_obs = J(6,3,0)

mat age_est = J(6,3,0)
mat age_se  = J(6,3,0)
mat age_obs = J(6,3,0)

mat llm_est = J(6,3,0)
mat llm_se  = J(6,3,0)
mat llm_obs = J(6,3,0)

forvalues h = 0/5 {               
	local i = `h' + 1
	
	use "$datgr/data_hetergraph_w`h'", clear	
	
	* Mover/Stayer
	reg lrw pm $controls if mover == 1, noconst cluster(idf)
	mat B = e(b)
	mat ms_est[`i',1] = _b[pm]
	mat ms_se[ `i',1] = _se[pm]
	mat ms_obs[`i',1] = e(N)
	reg lrw pm $controls if stay == 1, noconst cluster(idf)
	mat ms_est[`i',2] = _b[pm]
	mat ms_se[ `i',2] = _se[pm]
	mat ms_obs[`i',2] = e(N)	

	* Firm size
	cap drop firmsize 
	bysort idf idt: gen firmsize = _N       // recalculate firm size
	cap drop fsizegrp
	gen     fsizegrp = 1 if firmsize <= 10
	replace fsizegrp = 2 if firmsize >= 11  & firmsize <= 250 
	replace fsizegrp = 3 if firmsize >= 251  
	forvalues g = 1/3 {		
		reg lrw pm $controls if fsizegrp == `g', noconstant cluster(idf)			
		mat fsize1_est[`i',`g'] = _b[pm]
		mat fsize1_se[ `i',`g'] = _se[pm]
		mat fsize1_obs[`i',`g'] = e(N)			
	}	
	cap drop fsizegrp
	gen     fsizegrp = 1 if firmsize <= 10
	replace fsizegrp = 2 if firmsize >= 11  & firmsize <= 100 
	replace fsizegrp = 3 if firmsize >= 101  
	forvalues g = 1/3 {		
		reg lrw pm $controls if fsizegrp == `g', noconstant cluster(idf)			
		mat fsize2_est[`i',`g'] = _b[pm]
		mat fsize2_se[ `i',`g'] = _se[pm]
		mat fsize2_obs[`i',`g'] = e(N)			
	}	
	cap drop fsizegrp
	gen     fsizegrp = 1 if firmsize <= 10
	replace fsizegrp = 2 if firmsize >= 11  & firmsize <= 50 
	replace fsizegrp = 3 if firmsize >= 51  
	forvalues g = 1/3 {		
		reg lrw pm $controls if fsizegrp == `g', noconstant cluster(idf)			
		mat fsize3_est[`i',`g'] = _b[pm]
		mat fsize3_se[ `i',`g'] = _se[pm]
		mat fsize3_obs[`i',`g'] = e(N)			
	}	
	
	* Peer size
	cap drop peersize 
	bysort idf ido idt: gen peersize = _N     // recalculate peer size
	cap drop psizegrp
	gen     psizegrp = 1 if peersize <= 10
	replace psizegrp = 2 if peersize >= 11  & peersize <= 250 
	replace psizegrp = 3 if peersize >= 251  
	forvalues g = 1/3 {		
		reg lrw pm $controls if psizegrp == `g', noconstant cluster(idf)			
		mat psize1_est[`i',`g'] = _b[pm]
		mat psize1_se[ `i',`g'] = _se[pm]
		mat psize1_obs[`i',`g'] = e(N)			
	}	
	cap drop psizegrp
	gen     psizegrp = 1 if peersize <= 10
	replace psizegrp = 2 if peersize >= 11  & peersize <= 100 
	replace psizegrp = 3 if peersize >= 101  
	forvalues g = 1/3 {		
		reg lrw pm $controls if psizegrp == `g', noconstant cluster(idf)			
		mat psize2_est[`i',`g'] = _b[pm]
		mat psize2_se[ `i',`g'] = _se[pm]
		mat psize2_obs[`i',`g'] = e(N)			
	}	
	cap drop psizegrp
	gen     psizegrp = 1 if peersize <= 10
	replace psizegrp = 2 if peersize >= 11  & peersize <= 50 
	replace psizegrp = 3 if peersize >= 51  
	forvalues g = 1/3 {		
		reg lrw pm $controls if psizegrp == `g', noconstant cluster(idf)			
		mat psize3_est[`i',`g'] = _b[pm]
		mat psize3_se[ `i',`g'] = _se[pm]
		mat psize3_obs[`i',`g'] = e(N)			
	}	
	
	* Tenure
	cap drop tengrp
	gen     tengrp = 1 if (ten >= 0 & ten <= 1) & ten10 == 0
	replace tengrp = 2 if ten >= 2 & ten <= 3
	replace tengrp = 3 if ten >= 4 | ten10 == 1 	
	forvalues g = 1/3 {		
		reg lrw pm $controls if tengrp == `g', noconstant cluster(idf)		
		mat ten_est[`i',`g'] = _b[pm]
		mat ten_se[ `i',`g'] = _se[pm]
		mat ten_obs[`i',`g'] = e(N)			
	}	
	
	* Age heter
	cap drop agegrp
	gen     agegrp = 1 if age <= 30
	replace agegrp = 2 if age >= 31 & age <= 45
	replace agegrp = 3 if age >= 46 	
	forvalues g = 1/3 {		
		reg lrw pm $controls if agegrp == `g', noconstant cluster(idf)		
		mat age_est[`i',`g'] = _b[pm]
		mat age_se[ `i',`g'] = _se[pm]
		mat age_obs[`i',`g'] = e(N)				
	}
	
	* LLM heter
	cap drop llmgrp
	gen     llmgrp = 1 if llm_name == "PADOVA"
	replace llmgrp = 2 if llm_name == "VERONA"
	replace llmgrp = 3 if llm_name == "VENEZIA"
	forvalues g = 1/3 {		
		reg lrw pm $controls if llmgrp == `g', noconstant cluster(idf)		
		mat llm_est[`i',`g'] = _b[pm]
		mat llm_se[ `i',`g'] = _se[pm]
		mat llm_obs[`i',`g'] = e(N)				
	}


}

*-----------------------------------------------------------------------------
* Save estimates
*-----------------------------------------------------------------------------

local arg "est se obs"
local var "ms fsize1 fsize2 fsize3 psize1 psize2 psize3 ten age llm"

foreach v of local var {
foreach a of local arg {	
	clear 
	svmat `v'_`a'
	gen year = _n - 1
	save temp_`v'_`a', replace
}
}

clear
set obs 6
gen year = _n - 1
foreach v of local var {
foreach a of local arg {
	merge 1:1 year using temp_`v'_`a', nogen
	erase "temp_`v'_`a'.dta"
}
}
 
save "$datgr/estall_heter", replace


