* Some graph options
set scheme s2color
grstyle init
grstyle set plain, horizontal
grstyle set symbol
grstyle set symbolsize small
grstyle set lpattern
*grstyle set color Set1
grstyle set linewidth 0.5
grstyle linestyle legend none
grstyle set color edkblue cranberry orange green gray

*-----------------------------------------------------------------------------
* C.I.
*-----------------------------------------------------------------------------

use "$datgr/estall_heter", clear

* C.I.
forvalues i = 1/2 {
	gen ms_lo`i' = ms_est`i' - 1.96*ms_se`i'
	gen ms_up`i' = ms_est`i' + 1.96*ms_se`i'
}
local var "age ten fsize1 fsize2 fsize3 psize1 psize2 psize3 llm"
foreach v of local var {
	forvalues i = 1/3 {
		gen `v'_lo`i' = `v'_est`i' - 1.96*`v'_se`i'
		gen `v'_up`i' = `v'_est`i' + 1.96*`v'_se`i'
	}
}

*-----------------------------------------------------------------------------
* Heter graphs
*-----------------------------------------------------------------------------

* Graph
twoway (connect ms_est1 year, msize(vsmall)) ///
	   (connect ms_est2 year, msize(vsmall)) ///
	   (rarea ms_lo1 ms_up1 year, fcolor(edkblue%35) lwidth(none))    ///
	   (rarea ms_lo2 ms_up2 year, fcolor(cranberry%35) lwidth(none))  ///
 	   , ylabel(0(0.025)0.3, angle(0) format(%5.3f)) yscale(r(0 0.3)) ///
		 ytitle("Coefficients") xtitle("Year ahead (h)") ///
		 legend(order(1 "Movers" 2 "Stayers"))           ///
		 name(ms_ci, replace)
graph export "$graph/graph_hetermovestay_ci.pdf", as(pdf) replace		

local var "fsize psize"
foreach v of local var {
forvalues i = 1/3 {
	twoway (connect `v'`i'_est1 year, msize(vsmall)) ///
	   (connect `v'`i'_est2 year, msize(vsmall)) ///
	   (connect `v'`i'_est3 year, msize(vsmall)) ///
	   (rarea `v'`i'_lo1 `v'`i'_up1 year, fcolor(edkblue%35) lwidth(none))    ///
	   (rarea `v'`i'_lo2 `v'`i'_up2 year, fcolor(cranberry%35) lwidth(none))  ///
	   (rarea `v'`i'_lo3 `v'`i'_up3 year, fcolor(orange%35) lwidth(none))     ///
 	   , ylabel(0.075(0.025)0.3, angle(0) format(%5.3f)) yscale(r(0.075 0.3)) ///
		 ytitle("Coefficients") xtitle("Year ahead (h)") ///
		 legend(order(1 "2-10" 2 "11-50" 3 "50+") col(3))    ///
		 name(`v'`i'_ci, replace)
	graph export "$graph/graph_heter`v'`i'_ci.pdf", as(pdf) replace	
}
}

twoway (connect age_est1 year, msize(vsmall)) ///
	   (connect age_est2 year, msize(vsmall)) ///
	   (connect age_est3 year, msize(vsmall)) ///
	   (rarea age_lo1 age_up1 year, fcolor(edkblue%35) lwidth(none))    ///
	   (rarea age_lo2 age_up2 year, fcolor(cranberry%35) lwidth(none))  ///
	   (rarea age_lo3 age_up3 year, fcolor(orange%35) lwidth(none))     ///
 	   , ylabel(0(0.025)0.3, angle(0) format(%5.3f)) yscale(r(0 0.3)) ///
		 ytitle("Coefficients") xtitle("Year ahead (h)") ///
		 legend(order(1 "16-30" 2 "31-45" 3 "46-65") col(3))    ///
		 name(age_ci, replace)
graph export "$graph/graph_heterage_ci.pdf", as(pdf) replace	

twoway (connect ten_est1 year, msize(vsmall)) ///
	   (connect ten_est2 year, msize(vsmall)) ///
	   (connect ten_est3 year, msize(vsmall)) ///
	   (rarea ten_lo1 ten_up1 year, fcolor(edkblue%35) lwidth(none))    ///
	   (rarea ten_lo2 ten_up2 year, fcolor(cranberry%35) lwidth(none))  ///
	   (rarea ten_lo3 ten_up3 year, fcolor(orange%35) lwidth(none))     ///
 	   , ylabel(0(0.025)0.3, angle(0) format(%5.3f)) yscale(r(0 0.3)) ///
		 ytitle("Coefficients") xtitle("Year ahead (h)") ///
		 legend(order(1 "0-1" 2 "2-3" 3 "4+") col(3))    ///
		 name(ten_ci, replace)
graph export "$graph/graph_heterten_ci.pdf", as(pdf) replace	


*-----------------------------------------------------------------------------
* Appendix
*-----------------------------------------------------------------------------

twoway (connect llm_est1 year, lcolor(edkblue) mcolor(edkblue))              ///
       (rarea llm_lo1 llm_up1 year, fcolor(edkblue%35) lwidth(none))   ///
 	   , ytitle(Coefficients {&beta}) yscale(r(0.075 0.275))                ///
	     ylabel(0.075(0.025)0.275, angle(0) format(%5.3f) )                 ///
	     xlabel(0(1)5) xtitle(Year ahead (h))                              ///
		 legend(label(1 "Peer effect") label(2 "95% confidence interval")) ///
		 name(padova, replace)
graph export "$graph/baseline_robustpadova.pdf", as(pdf) replace		 

twoway (connect llm_est2 year, lcolor(edkblue) mcolor(edkblue))              ///
       (rarea llm_lo2 llm_up2 year, fcolor(edkblue%35) lwidth(none))   ///
 	   , ytitle(Coefficients {&beta}) yscale(r(0.075 0.275))                ///
	     ylabel(0.075(0.025)0.275, angle(0) format(%5.3f) )                 ///
	     xlabel(0(1)5) xtitle(Year ahead (h))                              ///
		 legend(label(1 "Peer effect") label(2 "95% confidence interval")) ///
		 name(verona, replace)
graph export "$graph/baseline_robustverona.pdf", as(pdf) replace		

twoway (connect llm_est3 year, lcolor(edkblue) mcolor(edkblue))              ///
       (rarea llm_lo3 llm_up3 year, fcolor(edkblue%35) lwidth(none))   ///
 	   , ytitle(Coefficients {&beta}) yscale(r(0.075 0.275))                ///
	     ylabel(0.075(0.025)0.275, angle(0) format(%5.3f) )                 ///
	     xlabel(0(1)5) xtitle(Year ahead (h))                              ///
		 legend(label(1 "Peer effect") label(2 "95% confidence interval")) ///
		 name(venice, replace)
graph export "$graph/baseline_robustvenice.pdf", as(pdf) replace		

